@@ -22,9 +22,11 @@
 
 namespace OCA\Activity\Tests;
 
+use OC\ActivityManager;
 use OCA\Activity\DataHelper;
 use OCA\Activity\GroupHelper;
 use OCA\Activity\ParameterHelper;
+use OCA\Activity\Tests\Mock\Extension;
 
 class GroupHelperTest extends TestCase {
 	public function groupHelperData() {
@@ -46,12 +48,12 @@ class GroupHelperTest extends TestCase {
 						'activity_id'	=> 1,
 						'user'			=> 'user',
 						'affecteduser'	=> 'affecteduser',
-						'app'			=> 'files',
-						'type'			=> 'file_created',
-						'subject'		=> 'created_self',
-						'subjectparams'	=> serialize(array('testing/file1.txt')),
+						'app'			=> 'app1',
+						'type'			=> 'type1',
+						'subject'		=> 'subject1',
+						'subjectparams'	=> json_encode(['testing/file1.txt']),
 						'message'		=> '',
-						'messageparams'	=> serialize(array()),
+						'messageparams'	=> json_encode([]),
 						'file'			=> 'testing/file1.txt',
 						'timestamp'		=> time(),
 					),
@@ -61,14 +63,14 @@ class GroupHelperTest extends TestCase {
 						'activity_id'	=> 1,
 						'user'			=> 'user',
 						'affecteduser'	=> 'affecteduser',
-						'app'			=> 'files',
-						'type'			=> 'file_created',
-						'subject'		=> 'created_self',
+						'app'			=> 'app1',
+						'type'			=> 'type1',
+						'subject'		=> 'subject1',
 						'subjectparams'	=> array('testing/file1.txt'),
 						'message'		=> '',
 						'messageparams'	=> array(),
 						'file'			=> 'testing/file1.txt',
-						'typeicon'		=> 'icon-add-color',
+						'typeicon'		=> 'icon-type1',
 					),
 				),
 			),
@@ -79,12 +81,12 @@ class GroupHelperTest extends TestCase {
 						'activity_id'	=> 1,
 						'user'			=> 'user',
 						'affecteduser'	=> 'affecteduser',
-						'app'			=> 'files',
-						'type'			=> 'file_created',
-						'subject'		=> 'created_self',
-						'subjectparams'	=> serialize(array('testing/file1.txt')),
+						'app'			=> 'app1',
+						'type'			=> 'type1',
+						'subject'		=> 'subject1',
+						'subjectparams'	=> json_encode(['testing/file1.txt']),
 						'message'		=> '',
-						'messageparams'	=> serialize(array()),
+						'messageparams'	=> json_encode([]),
 						'file'			=> 'testing/file1.txt',
 						'timestamp'		=> time(),
 					),
@@ -94,14 +96,14 @@ class GroupHelperTest extends TestCase {
 						'activity_id'	=> 1,
 						'user'			=> 'user',
 						'affecteduser'	=> 'affecteduser',
-						'app'			=> 'files',
-						'type'			=> 'file_created',
-						'subject'		=> 'created_self',
+						'app'			=> 'app1',
+						'type'			=> 'type1',
+						'subject'		=> 'subject1',
 						'subjectparams'	=> array('testing/file1.txt'),
 						'message'		=> '',
 						'messageparams'	=> array(),
 						'file'			=> 'testing/file1.txt',
-						'typeicon'		=> 'icon-add-color',
+						'typeicon'		=> 'icon-type1',
 					),
 				),
 			),
@@ -112,12 +114,12 @@ class GroupHelperTest extends TestCase {
 						'activity_id'	=> 2,
 						'user'			=> 'user',
 						'affecteduser'	=> 'affecteduser',
-						'app'			=> 'files',
-						'type'			=> 'file_created',
-						'subject'		=> 'created_self',
-						'subjectparams'	=> serialize(array('testing/file2.txt')),
+						'app'			=> 'app1',
+						'type'			=> 'type1',
+						'subject'		=> 'subject1',
+						'subjectparams'	=> json_encode(['testing/file2.txt']),
 						'message'		=> '',
-						'messageparams'	=> serialize(array()),
+						'messageparams'	=> json_encode([]),
 						'file'			=> 'testing/file2.txt',
 						'timestamp'		=> time(),
 					),
@@ -125,12 +127,12 @@ class GroupHelperTest extends TestCase {
 						'activity_id'	=> 1,
 						'user'			=> 'user',
 						'affecteduser'	=> 'affecteduser',
-						'app'			=> 'files',
-						'type'			=> 'file_created',
-						'subject'		=> 'created_self',
-						'subjectparams'	=> serialize(array('testing/file1.txt')),
+						'app'			=> 'app1',
+						'type'			=> 'type1',
+						'subject'		=> 'subject1',
+						'subjectparams'	=> json_encode(['testing/file1.txt']),
 						'message'		=> '',
-						'messageparams'	=> serialize(array()),
+						'messageparams'	=> json_encode([]),
 						'file'			=> 'testing/file1.txt',
 						'timestamp'		=> time(),
 					),
@@ -141,9 +143,9 @@ class GroupHelperTest extends TestCase {
 						'activity_ids'	=> array(2, 1),
 						'user'			=> 'user',
 						'affecteduser'	=> 'affecteduser',
-						'app'			=> 'files',
-						'type'			=> 'file_created',
-						'subject'		=> 'created_self',
+						'app'			=> 'app1',
+						'type'			=> 'type1',
+						'subject'		=> 'subject1',
 						'subjectparams'	=> array(array(
 							'testing/file2.txt',
 							'testing/file1.txt',
@@ -151,7 +153,7 @@ class GroupHelperTest extends TestCase {
 						'message'		=> '',
 						'messageparams'	=> array(),
 						'file'			=> 'testing/file2.txt',
-						'typeicon'		=> 'icon-add-color',
+						'typeicon'		=> 'icon-type1',
 					),
 				),
 			),
@@ -162,12 +164,12 @@ class GroupHelperTest extends TestCase {
 						'activity_id'	=> 3,
 						'user'			=> 'user',
 						'affecteduser'	=> 'affecteduser',
-						'app'			=> 'files',
-						'type'			=> 'file_created',
-						'subject'		=> 'created_self',
-						'subjectparams'	=> serialize(array('testing/file3.txt')),
+						'app'			=> 'app1',
+						'type'			=> 'type1',
+						'subject'		=> 'subject1',
+						'subjectparams'	=> json_encode(['testing/file3.txt']),
 						'message'		=> '',
-						'messageparams'	=> serialize(array()),
+						'messageparams'	=> json_encode([]),
 						'file'			=> 'testing/file3.txt',
 						'timestamp'		=> time(),
 					),
@@ -175,12 +177,12 @@ class GroupHelperTest extends TestCase {
 						'activity_id'	=> 2,
 						'user'			=> 'user',
 						'affecteduser'	=> 'affecteduser',
-						'app'			=> 'files',
-						'type'			=> 'file_created',
-						'subject'		=> 'created_self',
-						'subjectparams'	=> serialize(array('testing/file2.txt')),
+						'app'			=> 'app1',
+						'type'			=> 'type1',
+						'subject'		=> 'subject1',
+						'subjectparams'	=> json_encode(['testing/file2.txt']),
 						'message'		=> '',
-						'messageparams'	=> serialize(array()),
+						'messageparams'	=> json_encode([]),
 						'file'			=> 'testing/file2.txt',
 						'timestamp'		=> time(),
 					),
@@ -188,12 +190,12 @@ class GroupHelperTest extends TestCase {
 						'activity_id'	=> 1,
 						'user'			=> 'user',
 						'affecteduser'	=> 'affecteduser',
-						'app'			=> 'files',
-						'type'			=> 'shared',
-						'subject'		=> 'shared_link_self',
-						'subjectparams'	=> serialize(array('testing/file1.txt')),
+						'app'			=> 'app1',
+						'type'			=> 'NOTtype1',
+						'subject'		=> 'NOTsubject1',
+						'subjectparams'	=> json_encode(['testing/file1.txt']),
 						'message'		=> '',
-						'messageparams'	=> serialize(array()),
+						'messageparams'	=> json_encode([]),
 						'file'			=> 'testing/file1.txt',
 						'timestamp'		=> time() - 10,
 					),
@@ -204,9 +206,9 @@ class GroupHelperTest extends TestCase {
 						'activity_ids'	=> array(3, 2),
 						'user'			=> 'user',
 						'affecteduser'	=> 'affecteduser',
-						'app'			=> 'files',
-						'type'			=> 'file_created',
-						'subject'		=> 'created_self',
+						'app'			=> 'app1',
+						'type'			=> 'type1',
+						'subject'		=> 'subject1',
 						'subjectparams'	=> array(array(
 							'testing/file3.txt',
 							'testing/file2.txt',
@@ -214,20 +216,20 @@ class GroupHelperTest extends TestCase {
 						'message'		=> '',
 						'messageparams'	=> array(),
 						'file'			=> 'testing/file3.txt',
-						'typeicon'		=> 'icon-add-color',
+						'typeicon'		=> 'icon-type1',
 					),
 					array(
 						'activity_id'	=> 1,
 						'user'			=> 'user',
 						'affecteduser'	=> 'affecteduser',
-						'app'			=> 'files',
-						'type'			=> 'shared',
-						'subject'		=> 'shared_link_self',
+						'app'			=> 'app1',
+						'type'			=> 'NOTtype1',
+						'subject'		=> 'NOTsubject1',
 						'subjectparams'	=> array('testing/file1.txt'),
 						'message'		=> '',
 						'messageparams'	=> array(),
 						'file'			=> 'testing/file1.txt',
-						'typeicon'		=> 'icon-share',
+						'typeicon'		=> '',
 					),
 				),
 			),
@@ -238,12 +240,12 @@ class GroupHelperTest extends TestCase {
 						'activity_id'	=> 2,
 						'user'			=> 'user',
 						'affecteduser'	=> 'affecteduser',
-						'app'			=> 'files',
-						'type'			=> 'file_created',
-						'subject'		=> 'created_self',
-						'subjectparams'	=> serialize(array('testing/file2.txt')),
+						'app'			=> 'app1',
+						'type'			=> 'type1',
+						'subject'		=> 'subject1',
+						'subjectparams'	=> json_encode(['testing/file2.txt']),
 						'message'		=> '',
-						'messageparams'	=> serialize(array()),
+						'messageparams'	=> json_encode([]),
 						'file'			=> 'testing/file2.txt',
 						'timestamp'		=> time(),
 					),
@@ -251,12 +253,12 @@ class GroupHelperTest extends TestCase {
 						'activity_id'	=> 1,
 						'user'			=> 'user',
 						'affecteduser'	=> 'affecteduser',
-						'app'			=> 'files',
-						'type'			=> 'file_created',
-						'subject'		=> 'created_self',
-						'subjectparams'	=> serialize('testing/file1.txt'),
+						'app'			=> 'app1',
+						'type'			=> 'type1',
+						'subject'		=> 'subject1',
+						'subjectparams'	=> json_encode('testing/file1.txt'),
 						'message'		=> '',
-						'messageparams'	=> serialize(''),
+						'messageparams'	=> json_encode(''),
 						'file'			=> 'testing/file1.txt',
 						'timestamp'		=> time() - 1000000,
 					),
@@ -266,27 +268,27 @@ class GroupHelperTest extends TestCase {
 						'activity_id'	=> 2,
 						'user'			=> 'user',
 						'affecteduser'	=> 'affecteduser',
-						'app'			=> 'files',
-						'type'			=> 'file_created',
-						'subject'		=> 'created_self',
+						'app'			=> 'app1',
+						'type'			=> 'type1',
+						'subject'		=> 'subject1',
 						'subjectparams'	=> array('testing/file2.txt'),
 						'message'		=> '',
 						'messageparams'	=> array(),
 						'file'			=> 'testing/file2.txt',
-						'typeicon'		=> 'icon-add-color',
+						'typeicon'		=> 'icon-type1',
 					),
 					array(
 						'activity_id'	=> 1,
 						'user'			=> 'user',
 						'affecteduser'	=> 'affecteduser',
-						'app'			=> 'files',
-						'type'			=> 'file_created',
-						'subject'		=> 'created_self',
+						'app'			=> 'app1',
+						'type'			=> 'type1',
+						'subject'		=> 'subject1',
 						'subjectparams'	=> array('testing/file1.txt'),
 						'message'		=> '',
 						'messageparams'	=> array(''),
 						'file'			=> 'testing/file1.txt',
-						'typeicon'		=> 'icon-add-color',
+						'typeicon'		=> 'icon-type1',
 					),
 				),
 			),
@@ -297,12 +299,12 @@ class GroupHelperTest extends TestCase {
 						'activity_id'	=> 2,
 						'user'			=> 'user',
 						'affecteduser'	=> 'affecteduser',
-						'app'			=> 'files',
-						'type'			=> 'file_created',
-						'subject'		=> 'created_self',
-						'subjectparams'	=> serialize(array('testing/file2.txt')),
+						'app'			=> 'app1',
+						'type'			=> 'type1',
+						'subject'		=> 'subject1',
+						'subjectparams'	=> json_encode(['testing/file2.txt']),
 						'message'		=> '',
-						'messageparams'	=> serialize(array()),
+						'messageparams'	=> json_encode([]),
 						'file'			=> 'testing/file2.txt',
 						'timestamp'		=> time(),
 					),
@@ -310,12 +312,12 @@ class GroupHelperTest extends TestCase {
 						'activity_id'	=> 1,
 						'user'			=> 'user',
 						'affecteduser'	=> 'affecteduser',
-						'app'			=> 'files',
-						'type'			=> 'file_created',
-						'subject'		=> 'created_self',
-						'subjectparams'	=> serialize(array('testing/file1.txt')),
+						'app'			=> 'app1',
+						'type'			=> 'type1',
+						'subject'		=> 'subject1',
+						'subjectparams'	=> json_encode(['testing/file1.txt']),
 						'message'		=> '',
-						'messageparams'	=> serialize(array()),
+						'messageparams'	=> json_encode([]),
 						'file'			=> 'testing/file1.txt',
 						'timestamp'		=> time(),
 					),
@@ -325,27 +327,27 @@ class GroupHelperTest extends TestCase {
 						'activity_id'	=> 2,
 						'user'			=> 'user',
 						'affecteduser'	=> 'affecteduser',
-						'app'			=> 'files',
-						'type'			=> 'file_created',
-						'subject'		=> 'created_self',
+						'app'			=> 'app1',
+						'type'			=> 'type1',
+						'subject'		=> 'subject1',
 						'subjectparams'	=> array('testing/file2.txt'),
 						'message'		=> '',
 						'messageparams'	=> array(),
 						'file'			=> 'testing/file2.txt',
-						'typeicon'		=> 'icon-add-color',
+						'typeicon'		=> 'icon-type1',
 					),
 					array(
 						'activity_id'	=> 1,
 						'user'			=> 'user',
 						'affecteduser'	=> 'affecteduser',
-						'app'			=> 'files',
-						'type'			=> 'file_created',
-						'subject'		=> 'created_self',
+						'app'			=> 'app1',
+						'type'			=> 'type1',
+						'subject'		=> 'subject1',
 						'subjectparams'	=> array('testing/file1.txt'),
 						'message'		=> '',
 						'messageparams'	=> array(),
 						'file'			=> 'testing/file1.txt',
-						'typeicon'		=> 'icon-add-color',
+						'typeicon'		=> 'icon-type1',
 					),
 				),
 			),
@@ -356,12 +358,12 @@ class GroupHelperTest extends TestCase {
 						'activity_id'	=> 2,
 						'user'			=> 'user',
 						'affecteduser'	=> 'affecteduser',
-						'app'			=> 'NOTfiles',
-						'type'			=> 'file_created',
-						'subject'		=> 'created_self',
-						'subjectparams'	=> serialize(array('testing/file2.txt')),
+						'app'			=> 'NOTapp1',
+						'type'			=> 'type1',
+						'subject'		=> 'subject1',
+						'subjectparams'	=> json_encode(['testing/file2.txt']),
 						'message'		=> '',
-						'messageparams'	=> serialize(array()),
+						'messageparams'	=> json_encode([]),
 						'file'			=> 'testing/file2.txt',
 						'timestamp'		=> time(),
 					),
@@ -369,12 +371,12 @@ class GroupHelperTest extends TestCase {
 						'activity_id'	=> 1,
 						'user'			=> 'user',
 						'affecteduser'	=> 'affecteduser',
-						'app'			=> 'NOTfiles',
-						'type'			=> 'file_created',
-						'subject'		=> 'created_self',
-						'subjectparams'	=> serialize(array('testing/file1.txt')),
+						'app'			=> 'NOTapp1',
+						'type'			=> 'type1',
+						'subject'		=> 'subject1',
+						'subjectparams'	=> json_encode(['testing/file1.txt']),
 						'message'		=> '',
-						'messageparams'	=> serialize(array()),
+						'messageparams'	=> json_encode([]),
 						'file'			=> 'testing/file1.txt',
 						'timestamp'		=> time(),
 					),
@@ -384,27 +386,27 @@ class GroupHelperTest extends TestCase {
 						'activity_id'	=> 2,
 						'user'			=> 'user',
 						'affecteduser'	=> 'affecteduser',
-						'app'			=> 'NOTfiles',
-						'type'			=> 'file_created',
-						'subject'		=> 'created_self',
+						'app'			=> 'NOTapp1',
+						'type'			=> 'type1',
+						'subject'		=> 'subject1',
 						'subjectparams'	=> array('testing/file2.txt'),
 						'message'		=> '',
 						'messageparams'	=> array(),
 						'file'			=> 'testing/file2.txt',
-						'typeicon'		=> 'icon-add-color',
+						'typeicon'		=> 'icon-type1',
 					),
 					array(
 						'activity_id'	=> 1,
 						'user'			=> 'user',
 						'affecteduser'	=> 'affecteduser',
-						'app'			=> 'NOTfiles',
-						'type'			=> 'file_created',
-						'subject'		=> 'created_self',
+						'app'			=> 'NOTapp1',
+						'type'			=> 'type1',
+						'subject'		=> 'subject1',
 						'subjectparams'	=> array('testing/file1.txt'),
 						'message'		=> '',
 						'messageparams'	=> array(),
 						'file'			=> 'testing/file1.txt',
-						'typeicon'		=> 'icon-add-color',
+						'typeicon'		=> 'icon-type1',
 					),
 				),
 			),
@@ -415,12 +417,12 @@ class GroupHelperTest extends TestCase {
 						'activity_id'	=> 2,
 						'user'			=> 'user',
 						'affecteduser'	=> 'affecteduser',
-						'app'			=> 'files',
-						'type'			=> 'file_created',
-						'subject'		=> 'NOTcreated_self',
-						'subjectparams'	=> serialize(array('testing/file2.txt')),
+						'app'			=> 'app1',
+						'type'			=> 'type1',
+						'subject'		=> 'NOTsubject1',
+						'subjectparams'	=> json_encode(['testing/file2.txt']),
 						'message'		=> '',
-						'messageparams'	=> serialize(array()),
+						'messageparams'	=> json_encode([]),
 						'file'			=> 'testing/file2.txt',
 						'timestamp'		=> time(),
 					),
@@ -428,12 +430,12 @@ class GroupHelperTest extends TestCase {
 						'activity_id'	=> 1,
 						'user'			=> 'user',
 						'affecteduser'	=> 'affecteduser',
-						'app'			=> 'files',
-						'type'			=> 'file_created',
-						'subject'		=> 'NOTcreated_self',
-						'subjectparams'	=> serialize(array('testing/file1.txt')),
+						'app'			=> 'app1',
+						'type'			=> 'type1',
+						'subject'		=> 'NOTsubject1',
+						'subjectparams'	=> json_encode(['testing/file1.txt']),
 						'message'		=> '',
-						'messageparams'	=> serialize(array()),
+						'messageparams'	=> json_encode([]),
 						'file'			=> 'testing/file1.txt',
 						'timestamp'		=> time(),
 					),
@@ -443,27 +445,27 @@ class GroupHelperTest extends TestCase {
 						'activity_id'	=> 2,
 						'user'			=> 'user',
 						'affecteduser'	=> 'affecteduser',
-						'app'			=> 'files',
-						'type'			=> 'file_created',
-						'subject'		=> 'NOTcreated_self',
+						'app'			=> 'app1',
+						'type'			=> 'type1',
+						'subject'		=> 'NOTsubject1',
 						'subjectparams'	=> array('testing/file2.txt'),
 						'message'		=> '',
 						'messageparams'	=> array(),
 						'file'			=> 'testing/file2.txt',
-						'typeicon'		=> 'icon-add-color',
+						'typeicon'		=> 'icon-type1',
 					),
 					array(
 						'activity_id'	=> 1,
 						'user'			=> 'user',
 						'affecteduser'	=> 'affecteduser',
-						'app'			=> 'files',
-						'type'			=> 'file_created',
-						'subject'		=> 'NOTcreated_self',
+						'app'			=> 'app1',
+						'type'			=> 'type1',
+						'subject'		=> 'NOTsubject1',
 						'subjectparams'	=> array('testing/file1.txt'),
 						'message'		=> '',
 						'messageparams'	=> array(),
 						'file'			=> 'testing/file1.txt',
-						'typeicon'		=> 'icon-add-color',
+						'typeicon'		=> 'icon-type1',
 					),
 				),
 			),
@@ -474,12 +476,15 @@ class GroupHelperTest extends TestCase {
 	 * @dataProvider groupHelperData
 	 */
 	public function testGroupHelper($allowGrouping, $activities, $expected) {
-		$activityManager = $this->getMock('\OCP\Activity\IManager');
-		$activityManager->expects($this->any())
-			->method('getGroupParameter')
-			->with($this->anything())
-			->will($this->returnValue(false));
-		$activityLanguage = \OCP\Util::getL10N('activity');
+		$activityLanguage = \OCP\Util::getL10N('activity', 'en');
+		$activityManager = new ActivityManager(
+			$this->getMock('OCP\IRequest'),
+			$this->getMock('OCP\IUserSession'),
+			$this->getMock('OCP\IConfig')
+		);
+		$activityManager->registerExtension(function() use ($activityLanguage) {
+			return new Extension($activityLanguage, $this->getMock('\OCP\IURLGenerator'));
+		});
 
 		$helper = new GroupHelper(
 			$activityManager,
@@ -487,9 +492,11 @@ class GroupHelperTest extends TestCase {
 				$activityManager,
 				new ParameterHelper(
 					$activityManager,
-					new \OC\Files\View(''),
+					$this->getMockBuilder('OCP\IUserManager')->disableOriginalConstructor()->getMock(),
+					$this->getMockBuilder('OC\Files\View')->disableOriginalConstructor()->getMock(),
 					$this->getMockBuilder('OCP\IConfig')->disableOriginalConstructor()->getMock(),
-					$activityLanguage
+					$activityLanguage,
+					'test'
 				),
 				$activityLanguage
 			),
@@ -510,4 +517,47 @@ class GroupHelperTest extends TestCase {
 		}
 		$this->assertEquals($expected, $clearedResult);
 	}
+
+	public function testSetUser() {
+		/** @var GroupHelper $helper */
+		/** @var \PHPUnit_Framework_MockObject_MockObject $dataHelperMock */
+		list($helper, $dataHelperMock) = $this->setUpHelpers();
+
+		$dataHelperMock->expects($this->once())
+			->method('setUser')
+			->with('foobar');
+
+		$helper->setUser('foobar');
+	}
+
+	public function testSetL10n() {
+		/** @var GroupHelper $helper */
+		/** @var \PHPUnit_Framework_MockObject_MockObject $dataHelperMock */
+		list($helper, $dataHelperMock) = $this->setUpHelpers();
+		$l = \OCP\Util::getL10N('activity', 'de');
+
+		$dataHelperMock->expects($this->once())
+			->method('setL10n')
+			->with($l);
+
+		$helper->setL10n($l);
+	}
+
+	/**
+	 * Sets up the GroupHelper with a mocked DataHelper
+	 * @return array
+	 */
+	protected function setUpHelpers() {
+		$dataHelperMock = $this->getMockBuilder('OCA\Activity\DataHelper')
+			->disableOriginalConstructor()
+			->getMock();
+
+		$helper = new GroupHelper(
+			$this->getMockBuilder('OCP\Activity\IManager')->disableOriginalConstructor()->getMock(),
+			$dataHelperMock,
+			true
+		);
+
+		return [$helper, $dataHelperMock];
+	}
 }
