@@ -1,15 +1,19 @@
-<?php $TRANSLATIONS = array(
+<?php
+$TRANSLATIONS = array(
 "Contacts" => "Επαφές",
 "Add new LDAP Addressbook" => "Προσθήκη νέου βιβλίου διευθύνσεων LDAP",
 "Ok" => "Οκ",
 "Cancel" => "Άκυρο",
 "Save" => "Αποθήκευση",
 "Edit Addressbook" => "Επεξεργασία βιβλίου διευθύνσεων",
+"Import contacts" => "Εισαγωγή επαφών",
+"Upload file..." => "Μεταφόρτωση αρχείου...",
 "Starting file import" => "Έναρξη εισαγωγής αρχείου",
 "Format selected: {format}" => "Επιλεγμένη μορφοποίηση: {format}",
 "Automatic format detection" => "Αυτόματη ανίχνευση μορφοποίησης",
+"Import into..." => "Εισαγωγή σε...",
 "Processing {count}/{total} cards" => "Επεξεργασία {count}/{total} καρτών",
-"Total:{total}, Success:{imported}, Errors:{failed}" => "Σύνολο:{total}, Επιτυχείς:{imported}, Ανεπιτυχείς:{failed}",
+"Total: {total}, Success: {imported}, Errors: {failed}" => "Σύνολο: {total}, Επιτυχείς: {imported}, Σφάλματα: {failed}",
 "An address book called {name} already exists" => "Το βιβλίο διευθύνσεων με το όνομα {name} υπάρχει ήδη ",
 "Failed adding address book: {error}" => "Αποτυχία πρόσθεσης βιβλίου διευθύνσεων: {error}",
 "Failed loading address books: {error}" => "Αποτυχία φόρτωσης βιβλίων διευθύνσεων: {error}",
@@ -54,7 +58,6 @@
 "Contacts are not in this group." => "Οι επαφές δεν είναι σε αυτήν την ομάδα.",
 "A group named \"{group}\" already exists" => "Μια ομάδα με το όνομα \"{group}\" υπάρχει ήδη",
 "Failed renaming group: {error}" => "Σφάλμα μετονομασίας της ομάδας: {error}",
-"You can drag groups to\narrange them as you like." => "Μπορείτε να σύρετε τις ομάδες για να\nτις τακτοποιήσετε όπως θέλετε.",
 "Failed adding group: {error}" => "Σφάλμα προσθήκης της ομάδας: {error}",
 "All" => "Όλες",
 "Favorites" => "Αγαπημένες",
@@ -62,13 +65,12 @@
 "Not grouped" => "Οχι ομαδοποιημένα",
 "Failed loading groups: {error}" => "Σφάλμα φόρτωσης της ομάδας: {error}",
 "Please choose the addressbook" => "Παρακαλώ επιλέξτε το βιβλίο διευθύνσεων",
-"Import into..." => "Εισαγωγή σε...",
 "Error loading import template" => "Σφάλμα φόρτωσης προτύπου",
-"Import contacts" => "Εισαγωγή επαφών",
 "Import" => "Εισαγωγή",
 "Importing..." => "Γίνεται εισαγωγή...",
 "Import done" => "Η εισαγωγή ολοκληρώθηκε",
 "Close" => "Κλείσιμο",
+"Contact" => "Επαφή",
 "Error, missing parameters: " => "Σφάλμα, ελλιπείς παράμετροι:",
 "Failed loading photo: {error}" => "Αποτυχία φόρτωσης φωτογραφίας: {error}",
 "You do not have permissions to see this contact" => "Δεν έχετε άδεια να δείτε αυτή την επαφή",
@@ -116,6 +118,7 @@
 "Error saving contact." => "Σφάλμα κατά την αποθήκευση επαφής.",
 "No group name given." => "Δεν δόθηκε όνομα ομάδας.",
 "Error adding group." => "Σφάλμα κατά την προσθήκη ομάδας.",
+"No group ID given." => "Δεν δόθηκε ID ομάδας.",
 "No group name to rename from given." => "Κανένα όνομα ομάδας για μετονομασία από το δοθέν.",
 "No group name to rename to given." => "Κανένα όνομα ομάδας για μετονομασία στο δοθέν.",
 "Error renaming group." => "Σφάλμα κατά τη μετονομασία της ομάδας",
@@ -141,7 +144,6 @@
 "No key is given." => "Δεν δόθηκε κλειδί.",
 "No value is given." => "Δεν δόθηκε τιμή.",
 "Could not set preference: " => "Αδυναμία ορισμού προτίμησης:",
-"Contact" => "Επαφή",
 "Other" => "Άλλο",
 "HomePage" => "Αρχική Σελίδα",
 "Jabber" => "Jabber",
@@ -180,8 +182,6 @@
 "Display name" => "Προβαλλόμενο όνομα",
 "Add Address Book" => "Προσθήκη Βιβλίου Διευθύνσεων",
 "Add LDAP Address Book" => "Προσθήκη βιβλίου διευθύνσεων LDAP",
-"Automatic format" => "Αυτόματη μορφοποίηση",
-"Select file..." => "Επιλογή αρχείου...",
 "(De-)select all" => "(Απο-)επιλογή όλων",
 "Sort order" => "Σειρά ταξινόμησης",
 "First- Lastname" => "Όνομα- Επίθετο",
@@ -207,7 +207,7 @@
 "Add new addressbook" => "Προσθήκη νέου βιβλίου επαφών",
 "Delete current contact" => "Διαγραφή τρέχουσας επαφής",
 "You have no contacts in your address book or your address book is disabled." => "Δεν έχετε καθόλου επαφές στο βιβλίο διευθύνσεών σας ή το βιβλίο διευθύνσεων σας είναι απενεργοποιημένο.",
-"Add a new contact or import existing contacts from a VCF file." => "Προσθέστε μια νέα επαφή ή εισαγάγετε υπάρχουσες επαφές από ένα VCF αρχείο.",
+"Add a new contact or import existing contacts from a file (VCF, CSV or LDIF)." => "Προσθέστε μια νέα επαφή ή εισαγάγετε υπάρχουσες επαφές από ένα αρχείο (VCF, CSV ή LDIF).",
 "Which contact should the data be merged into?" => "Με ποιά επαφή θα θέλατε να συγχωνευτούν τα δεδομένα?",
 "Delete the other(s) after successful merge?" => "Διαγραφή του(ων) άλλου(ων) μετά την επιτυχή συγχώνευση?",
 "Compose mail" => "Σύνθεση μηνύματος",
@@ -251,6 +251,9 @@
 "Export" => "Εξαγωγή",
 "CardDAV link" => "Σύνδεσμος CardDAV",
 "Edit" => "Επεξεργασία",
+"Format" => "Μορφοποίηση",
+"Automatic format" => "Αυτόματη μορφοποίηση",
+"Select file..." => "Επιλογή αρχείου...",
 "Addressbook URI" => "Διεύθυνση URI βιβλίου διευθύνσεων",
 "URI" => "Διεύθυνση URI",
 "Description" => "Περιγραφή",
@@ -271,3 +274,4 @@
 "Connector value (Better use external editor and copy/paste)" => "Μεταβλητή συνδέσμου (Καλύτερα χρησιμοποιείστε εξωτερικό επεξεργαστή και αντιγράψτε/επικολλήστε)",
 "Copy from (Warning, replaces current custom value)" => "Αντιγραφή από (Προσοχή, αντικαθιστά την τρέχουσα προσαρμοσμένη τιμή)"
 );
+$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
