@@ -4,9 +4,6 @@ OC.L10N.register(
     "Rename" : "Nimeä uudelleen",
     "Delete" : "Poista",
     "Error" : "Virhe",
-    "_%n folder_::_%n folders_" : ["",""],
-    "_%n file_::_%n files_" : ["",""],
-    "_Uploading %n file_::_Uploading %n files_" : ["",""],
     "Favorite" : "Suosikit",
     "Save" : "Tallenna",
     "Settings" : "Asetukset",
