@@ -7,10 +7,6 @@ OC.L10N.register(
     "Delete" : "ਹਟਾਓ",
     "Download" : "ਡਾਊਨਲੋਡ",
     "Error" : "ਗਲਤੀ",
-    "_%n folder_::_%n folders_" : ["",""],
-    "_%n file_::_%n files_" : ["",""],
-    "_Uploading %n file_::_Uploading %n files_" : ["",""],
-    "_matches '{filter}'_::_match '{filter}'_" : ["",""],
     "Settings" : "ਸੈਟਿੰਗ",
     "Upload" : "ਅੱਪਲੋਡ",
     "Cancel upload" : "ਅੱਪਲੋਡ ਰੱਦ ਕਰੋ"
