@@ -5,10 +5,6 @@ OC.L10N.register(
     "Error" : "పొరపాటు",
     "Name" : "పేరు",
     "Size" : "పరిమాణం",
-    "_%n folder_::_%n folders_" : ["",""],
-    "_%n file_::_%n files_" : ["",""],
-    "_Uploading %n file_::_Uploading %n files_" : ["",""],
-    "_matches '{filter}'_::_match '{filter}'_" : ["",""],
     "Save" : "భద్రపరచు",
     "Settings" : "అమరికలు",
     "New folder" : "కొత్త సంచయం",
