@@ -7,10 +7,6 @@ OC.L10N.register(
     "Download" : "ڈاؤن لوڈ،",
     "Error" : "ایرر",
     "Name" : "اسم",
-    "_%n folder_::_%n folders_" : ["",""],
-    "_%n file_::_%n files_" : ["",""],
-    "_Uploading %n file_::_Uploading %n files_" : ["",""],
-    "_matches '{filter}'_::_match '{filter}'_" : ["",""],
     "Save" : "حفظ",
     "Settings" : "ترتیبات"
 },
