@@ -3,8 +3,14 @@ OC.L10N.register(
     {
     "Please provide a valid Dropbox app key and secret." : "Prezintă te rog o cheie de Dropbox validă și parola",
     "External storage" : "Stocare externă",
+    "Local" : "Local",
     "Location" : "Locație",
     "Amazon S3" : "Amazon S3",
+    "Key" : "Cheie",
+    "Secret" : "Secret",
+    "Access Key" : "Cheie de acces",
+    "Secret Key" : "Cheie secretă",
+    "Hostname" : "Hostname",
     "Port" : "Portul",
     "Region" : "Regiune",
     "Host" : "Gazdă",
@@ -12,6 +18,7 @@ OC.L10N.register(
     "Password" : "Parolă",
     "Share" : "Partajează",
     "URL" : "URL",
+    "Public key" : "Cheie publică",
     "Access granted" : "Acces permis",
     "Error configuring Dropbox storage" : "Eroare la configurarea mediului de stocare Dropbox",
     "Grant access" : "Permite accesul",
