@@ -1,37 +1,84 @@
 <?php
 /**
- * ownCloud
+ * @author Björn Schießle <schiessle@owncloud.com>
+ * @author Joas Schilling <nickvergessen@owncloud.com>
+ * @author Morris Jobke <hey@morrisjobke.de>
+ * @author Robin Appelman <icewind@owncloud.com>
+ * @author Robin McCorkell <rmccorkell@karoshi.org.uk>
+ * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @author Vincent Petry
- * Copyright (c) 2013 Vincent Petry <pvince81@owncloud.com>
+ * @copyright Copyright (c) 2015, ownCloud, Inc.
+ * @license AGPL-3.0
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU AFFERO GENERAL PUBLIC LICENSE
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or any later version.
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3,
+ * as published by the Free Software Foundation.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU AFFERO GENERAL PUBLIC LICENSE for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
  *
- * You should have received a copy of the GNU Affero General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU Affero General Public License, version 3,
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>
  *
  */
 
-class Test_Mount_Config_Dummy_Storage {
+class Test_Mount_Config_Dummy_Storage extends \OC\Files\Storage\Common {
 	public function __construct($params) {
 		if (isset($params['simulateFail']) && $params['simulateFail'] == true) {
 			throw new \Exception('Simulated config validation fail');
 		}
 	}
 
+	public function getId() {
+		return 'dummy_storage';
+	}
+
+	public function mkdir($path) {
+		return false;
+	}
+
+	public function rmdir($path) {
+		return false;
+	}
+
+	public function opendir($path) {
+		return false;
+	}
+
+	public function filetype($path) {
+		return false;
+	}
+
+	public function file_exists($path) {
+		return false;
+	}
+
+	public function unlink($path) {
+		return false;
+	}
+
+	public function fopen($path, $mode) {
+		return false;
+	}
+
+	public function touch($path, $mtime = null) {
+		return false;
+	}
+
+	public function stat($path) {
+		return false;
+	}
+
 	public function test() {
 		return true;
 	}
 }
 
+class Test_Mount_Config_Storage_No_Personal extends Test_Mount_Config_Dummy_Storage {
+}
+
 class Test_Mount_Config_Hook_Test {
 	static $signal;
 	static $params;
@@ -76,7 +123,6 @@ class Test_Mount_Config extends \Test\TestCase {
 	private $dataDir;
 	private $userHome;
 	private $oldAllowedBackends;
-	private $allBackends;
 
 	const TEST_USER1 = 'user1';
 	const TEST_USER2 = 'user2';
@@ -94,6 +140,12 @@ class Test_Mount_Config extends \Test\TestCase {
 				'configuration' => array()
 			)
 		);
+		OC_Mount_Config::registerBackend('Test_Mount_Config_Storage_No_Personal', array(
+				'backend' => 'dummy no personal',
+				'priority' => 150,
+				'configuration' => array()
+			)
+		);
 
 		\OC_User::createUser(self::TEST_USER1, self::TEST_USER1);
 		\OC_User::createUser(self::TEST_USER2, self::TEST_USER2);
@@ -120,11 +172,10 @@ class Test_Mount_Config extends \Test\TestCase {
 			'user_mounting_backends',
 			''
 		);
-		$this->allBackends = OC_Mount_Config::getBackends();
 		OCP\Config::setAppValue(
 			'files_external',
 			'user_mounting_backends',
-			implode(',', array_keys($this->allBackends))
+			'Test_Mount_Config_Dummy_Storage'
 		);
 
 		OC_Mount_Config::$skipTest = true;
@@ -161,6 +212,11 @@ class Test_Mount_Config extends \Test\TestCase {
 		return json_decode(file_get_contents($configFile), true);
 	}
 
+	private function writeGlobalConfig($config) {
+		$configFile = $this->dataDir . '/mount.json';
+		file_put_contents($configFile, json_encode($config));
+	}
+
 	/**
 	 * Reads the user config, for checking
 	 */
@@ -203,7 +259,7 @@ class Test_Mount_Config extends \Test\TestCase {
 			'password' => '12345',
 		);
 
-		$this->assertEquals(true, OC_Mount_Config::addMountPoint('/ext', '\OC\Files\Storage\SFTP', $storageOptions, $mountType, $applicable, $isPersonal));
+		$this->assertEquals(0, OC_Mount_Config::addMountPoint('/ext', 'Test_Mount_Config_Dummy_Storage', $storageOptions, $mountType, $applicable, $isPersonal));
 
 		$config = $this->readGlobalConfig();
 		$this->assertEquals(1, count($config));
@@ -211,7 +267,7 @@ class Test_Mount_Config extends \Test\TestCase {
 		$this->assertTrue(isset($config[$mountType][$applicable]));
 		$this->assertTrue(isset($config[$mountType][$applicable]['/$user/files/ext']));
 		$this->assertEquals(
-			'\OC\Files\Storage\SFTP',
+			'Test_Mount_Config_Dummy_Storage',
 			$config[$mountType][$applicable]['/$user/files/ext']['class']
 		);
 	}
@@ -230,7 +286,7 @@ class Test_Mount_Config extends \Test\TestCase {
 			'password' => '12345',
 		);
 
-		$this->assertEquals(true, OC_Mount_Config::addMountPoint('/ext', '\OC\Files\Storage\SFTP', $storageOptions, $mountType, $applicable, $isPersonal));
+		$this->assertEquals(0, OC_Mount_Config::addMountPoint('/ext', 'Test_Mount_Config_Dummy_Storage', $storageOptions, $mountType, $applicable, $isPersonal));
 
 		$config = $this->readUserConfig();
 		$this->assertEquals(1, count($config));
@@ -238,7 +294,7 @@ class Test_Mount_Config extends \Test\TestCase {
 		$this->assertTrue(isset($config[$mountType][$applicable]));
 		$this->assertTrue(isset($config[$mountType][$applicable]['/' . self::TEST_USER1 . '/files/ext']));
 		$this->assertEquals(
-			'\OC\Files\Storage\SFTP',
+			'Test_Mount_Config_Dummy_Storage',
 			$config[$mountType][$applicable]['/' . self::TEST_USER1 . '/files/ext']['class']
 		);
 	}
@@ -252,14 +308,7 @@ class Test_Mount_Config extends \Test\TestCase {
 		$isPersonal = true;
 
 		// local
-		$this->assertFalse(OC_Mount_Config::addMountPoint('/ext', '\OC\Files\storage\local', array(), $mountType, $applicable, $isPersonal));
-
-		unset($this->allBackends['\OC\Files\Storage\SFTP']);
-		OCP\Config::setAppValue(
-			'files_external',
-			'user_mounting_backends',
-			implode(',', array_keys($this->allBackends))
-		);
+		$this->assertFalse(OC_Mount_Config::addMountPoint('/ext', '\OC\Files\Storage\Local', array(), $mountType, $applicable, $isPersonal));
 
 		$storageOptions = array(
 			'host' => 'localhost',
@@ -268,7 +317,7 @@ class Test_Mount_Config extends \Test\TestCase {
 		);
 
 		// non-local but forbidden
-		$this->assertFalse(OC_Mount_Config::addMountPoint('/ext', '\OC\Files\Storage\SFTP', $storageOptions, $mountType, $applicable, $isPersonal));
+		$this->assertFalse(OC_Mount_Config::addMountPoint('/ext', 'Test_Mount_Config_Storage_No_Personal', $storageOptions, $mountType, $applicable, $isPersonal));
 
 		$this->assertFalse(file_exists($this->userHome . '/mount.json'));
 	}
@@ -340,10 +389,11 @@ class Test_Mount_Config extends \Test\TestCase {
 		);
 
 		// write config
-		$this->assertTrue(
+		$this->assertEquals(
+			0,
 			OC_Mount_Config::addMountPoint(
 				'/ext',
-				'\OC\Files\Storage\SMB',
+				'Test_Mount_Config_Dummy_Storage',
 				$options,
 				$mountType,
 				$applicable,
@@ -354,7 +404,7 @@ class Test_Mount_Config extends \Test\TestCase {
 		// re-read config
 		$config = OC_Mount_Config::getSystemMountPoints();
 		$this->assertEquals(1, count($config));
-		$this->assertEquals('\OC\Files\Storage\SMB', $config[0]['class']);
+		$this->assertEquals('Test_Mount_Config_Dummy_Storage', $config[0]['class']);
 		$this->assertEquals('ext', $config[0]['mountpoint']);
 		$this->assertEquals($expectApplicableArray, $config[0]['applicable']);
 		$savedOptions = $config[0]['options'];
@@ -380,10 +430,11 @@ class Test_Mount_Config extends \Test\TestCase {
 		);
 
 		// write config
-		$this->assertTrue(
+		$this->assertEquals(
+			0,
 			OC_Mount_Config::addMountPoint(
 				'/ext',
-				'\OC\Files\Storage\SMB',
+				'Test_Mount_Config_Dummy_Storage',
 				$options,
 				$mountType,
 				$applicable,
@@ -394,7 +445,7 @@ class Test_Mount_Config extends \Test\TestCase {
 		// re-read config
 		$config = OC_Mount_Config::getPersonalMountPoints();
 		$this->assertEquals(1, count($config));
-		$this->assertEquals('\OC\Files\Storage\SMB', $config[0]['class']);
+		$this->assertEquals('Test_Mount_Config_Dummy_Storage', $config[0]['class']);
 		$this->assertEquals('ext', $config[0]['mountpoint']);
 		$savedOptions = $config[0]['options'];
 		$this->assertEquals($options, $savedOptions);
@@ -417,10 +468,11 @@ class Test_Mount_Config extends \Test\TestCase {
 		);
 
 		// write config
-		$this->assertTrue(
+		$this->assertEquals(
+			0,
 			OC_Mount_Config::addMountPoint(
 				$mountPoint,
-				'\OC\Files\Storage\SMB',
+				'Test_Mount_Config_Dummy_Storage',
 				$mountConfig,
 				$mountType,
 				$applicable,
@@ -450,10 +502,11 @@ class Test_Mount_Config extends \Test\TestCase {
 
 		// edit
 		$mountConfig['host'] = 'anothersmbhost';
-		$this->assertTrue(
+		$this->assertEquals(
+			0,
 			OC_Mount_Config::addMountPoint(
 				$mountPoint,
-				'\OC\Files\Storage\SMB',
+				'Test_Mount_Config_Dummy_Storage',
 				$mountConfig,
 				$mountType,
 				$applicable,
@@ -515,10 +568,11 @@ class Test_Mount_Config extends \Test\TestCase {
 		);
 
 		// write config
-		$this->assertTrue(
+		$this->assertEquals(
+			0,
 			OC_Mount_Config::addMountPoint(
 				'/ext',
-				'\OC\Files\Storage\SMB',
+				'Test_Mount_Config_Dummy_Storage',
 				$mountConfig,
 				$mountType,
 				$applicable,
@@ -556,10 +610,11 @@ class Test_Mount_Config extends \Test\TestCase {
 		);
 
 		// write config
-		$this->assertTrue(
+		$this->assertEquals(
+			0,
 			OC_Mount_Config::addMountPoint(
 				'/ext',
-				'\OC\Files\Storage\SMB',
+				'Test_Mount_Config_Dummy_Storage',
 				$mountConfig,
 				$mountType,
 				$applicable,
@@ -579,6 +634,51 @@ class Test_Mount_Config extends \Test\TestCase {
 		$this->assertEquals($mountConfig, $savedMountConfig);
 	}
 
+	public function testVariableSubstitution() {
+		$legacyBackendOptions = [
+			'user' => 'someuser',
+			'password' => 'somepassword',
+			'replacethis' => '$user',
+		];
+		$legacyBackendOptions = \OC_Mount_Config::encryptPasswords($legacyBackendOptions);
+
+		$legacyConfig = [
+			'class' => '\OC\Files\Storage\SMB',
+			'options' => $legacyBackendOptions,
+			'mountOptions' => ['preview' => false, 'int' => 1],
+		];
+		// different mount options
+		$legacyConfig2 = [
+			'class' => '\OC\Files\Storage\SMB',
+			'options' => $legacyBackendOptions,
+			'mountOptions' => ['preview' => true, 'string' => 'abc'],
+		];
+
+		$json = [
+			'user' => [
+				self::TEST_USER1 => [
+					'/$user/files/somemount' => $legacyConfig,
+					'/$user/files/anothermount' => $legacyConfig2,
+				],
+			],
+		];
+
+		$this->writeGlobalConfig($json);
+
+		// re-read config, password was read correctly
+		$config = OC_Mount_Config::getAbsoluteMountPoints(self::TEST_USER1);
+
+		$config1 = $config['/' . self::TEST_USER1 . '/files/somemount'];
+		$config2 = $config['/' . self::TEST_USER1 . '/files/anothermount'];
+
+		$this->assertSame(self::TEST_USER1, $config1['options']['replacethis']);
+		$this->assertSame(self::TEST_USER1, $config1['options']['replacethis']);
+		$this->assertSame(1, $config1['mountOptions']['int']);
+		$this->assertSame(true, $config2['mountOptions']['preview']);
+		$this->assertSame('abc', $config2['mountOptions']['string']);
+	}
+
+
 	public function mountDataProvider() {
 		return array(
 			// Tests for visible mount points
@@ -665,10 +765,11 @@ class Test_Mount_Config extends \Test\TestCase {
 		);
 
 		// add mount point as "test" user
-		$this->assertTrue(
+		$this->assertEquals(
+			0,
 			OC_Mount_Config::addMountPoint(
 				'/ext',
-				'\OC\Files\Storage\SMB',
+				'Test_Mount_Config_Dummy_Storage',
 				$mountConfig,
 				$mountType,
 				$applicable,
@@ -683,7 +784,7 @@ class Test_Mount_Config extends \Test\TestCase {
 		if ($expectVisible) {
 			$this->assertEquals(1, count($mountPoints));
 			$this->assertTrue(isset($mountPoints['/' . self::TEST_USER1 . '/files/ext']));
-			$this->assertEquals('\OC\Files\Storage\SMB', $mountPoints['/' . self::TEST_USER1 . '/files/ext']['class']);
+			$this->assertEquals('Test_Mount_Config_Dummy_Storage', $mountPoints['/' . self::TEST_USER1 . '/files/ext']['class']);
 			$this->assertEquals($mountConfig, $mountPoints['/' . self::TEST_USER1 . '/files/ext']['options']);
 		}
 		else {
@@ -708,10 +809,11 @@ class Test_Mount_Config extends \Test\TestCase {
 		);
 
 		// write config
-		$this->assertTrue(
+		$this->assertEquals(
+			0,
 			OC_Mount_Config::addMountPoint(
 				'/ext',
-				'\OC\Files\Storage\SMB',
+				'Test_Mount_Config_Dummy_Storage',
 				$options,
 				OC_Mount_Config::MOUNT_TYPE_USER,
 				self::TEST_USER1,
@@ -719,10 +821,11 @@ class Test_Mount_Config extends \Test\TestCase {
 			)
 		);
 
-		$this->assertTrue(
+		$this->assertEquals(
+			0,
 			OC_Mount_Config::addMountPoint(
 				'/ext',
-				'\OC\Files\Storage\SMB',
+				'Test_Mount_Config_Dummy_Storage',
 				$options,
 				OC_Mount_Config::MOUNT_TYPE_USER,
 				self::TEST_USER2,
@@ -730,10 +833,11 @@ class Test_Mount_Config extends \Test\TestCase {
 			)
 		);
 
-		$this->assertTrue(
+		$this->assertEquals(
+			0,
 			OC_Mount_Config::addMountPoint(
 				'/ext',
-				'\OC\Files\Storage\SMB',
+				'Test_Mount_Config_Dummy_Storage',
 				$options,
 				OC_Mount_Config::MOUNT_TYPE_GROUP,
 				self::TEST_GROUP2,
@@ -741,10 +845,11 @@ class Test_Mount_Config extends \Test\TestCase {
 			)
 		);
 
-		$this->assertTrue(
+		$this->assertEquals(
+			0,
 			OC_Mount_Config::addMountPoint(
 				'/ext',
-				'\OC\Files\Storage\SMB',
+				'Test_Mount_Config_Dummy_Storage',
 				$options,
 				OC_Mount_Config::MOUNT_TYPE_GROUP,
 				self::TEST_GROUP1,
@@ -755,7 +860,7 @@ class Test_Mount_Config extends \Test\TestCase {
 		// re-read config
 		$config = OC_Mount_Config::getSystemMountPoints();
 		$this->assertEquals(1, count($config));
-		$this->assertEquals('\OC\Files\Storage\SMB', $config[0]['class']);
+		$this->assertEquals('Test_Mount_Config_Dummy_Storage', $config[0]['class']);
 		$this->assertEquals('ext', $config[0]['mountpoint']);
 		$this->assertEquals($options, $config[0]['options']);
 		$this->assertEquals(array(self::TEST_USER1, self::TEST_USER2), $config[0]['applicable']['users']);
@@ -779,10 +884,11 @@ class Test_Mount_Config extends \Test\TestCase {
 		);
 
 		// write config
-		$this->assertTrue(
+		$this->assertEquals(
+			0,
 			OC_Mount_Config::addMountPoint(
 				'/ext',
-				'\OC\Files\Storage\SMB',
+				'Test_Mount_Config_Dummy_Storage',
 				$options1,
 				$mountType,
 				self::TEST_USER1,
@@ -797,10 +903,11 @@ class Test_Mount_Config extends \Test\TestCase {
 			'share' => 'anothersmbshare',
 			'root' => 'anothersmbroot'
 		);
-		$this->assertTrue(
+		$this->assertEquals(
+			0,
 			OC_Mount_Config::addMountPoint(
 				'/ext',
-				'\OC\Files\Storage\SMB',
+				'Test_Mount_Config_Dummy_Storage',
 				$options2,
 				$mountType,
 				self::TEST_USER2,
@@ -811,10 +918,10 @@ class Test_Mount_Config extends \Test\TestCase {
 		// re-read config
 		$config = OC_Mount_Config::getSystemMountPoints();
 		$this->assertEquals(2, count($config));
-		$this->assertEquals('\OC\Files\Storage\SMB', $config[0]['class']);
+		$this->assertEquals('Test_Mount_Config_Dummy_Storage', $config[0]['class']);
 		$this->assertEquals('ext', $config[0]['mountpoint']);
 		$this->assertEquals($options1, $config[0]['options']);
-		$this->assertEquals('\OC\Files\Storage\SMB', $config[1]['class']);
+		$this->assertEquals('Test_Mount_Config_Dummy_Storage', $config[1]['class']);
 		$this->assertEquals('ext', $config[1]['mountpoint']);
 		$this->assertEquals($options2, $config[1]['options']);
 	}
@@ -910,10 +1017,11 @@ class Test_Mount_Config extends \Test\TestCase {
 
 		// Add mount points
 		foreach($mounts as $i => $mount) {
-			$this->assertTrue(
+			$this->assertEquals(
+				0,
 				OC_Mount_Config::addMountPoint(
 					'/ext',
-					'\OC\Files\Storage\SMB',
+					'Test_Mount_Config_Dummy_Storage',
 					$mountConfig + array('id' => $i),
 					$mount['mountType'],
 					$mount['applicable'],
@@ -935,7 +1043,7 @@ class Test_Mount_Config extends \Test\TestCase {
 	 */
 	public function testPriorityPersistence() {
 
-		$class = '\OC\Files\Storage\SMB';
+		$class = 'Test_Mount_Config_Dummy_Storage';
 		$priority = 123;
 		$mountConfig = array(
 			'host' => 'somehost',
@@ -945,7 +1053,8 @@ class Test_Mount_Config extends \Test\TestCase {
 			'share' => '',
 		);
 
-		$this->assertTrue(
+		$this->assertEquals(
+			0,
 			OC_Mount_Config::addMountPoint(
 				'/ext',
 				$class,
@@ -963,7 +1072,8 @@ class Test_Mount_Config extends \Test\TestCase {
 			$mountPoints['/'.self::TEST_USER1.'/files/ext']['priority']);
 
 		// Simulate changed mount options (without priority set)
-		$this->assertTrue(
+		$this->assertEquals(
+			0,
 			OC_Mount_Config::addMountPoint(
 				'/ext',
 				$class,
@@ -993,10 +1103,11 @@ class Test_Mount_Config extends \Test\TestCase {
 		);
 
 		// Create personal mount point
-		$this->assertTrue(
+		$this->assertEquals(
+			0,
 			OC_Mount_Config::addMountPoint(
 				'/ext',
-				'\OC\Files\Storage\SMB',
+				'Test_Mount_Config_Dummy_Storage',
 				$mountConfig,
 				OC_Mount_Config::MOUNT_TYPE_USER,
 				self::TEST_USER1,
@@ -1012,7 +1123,7 @@ class Test_Mount_Config extends \Test\TestCase {
 		$this->assertEquals(0, count($mountPointsMe));
 		$this->assertEquals(1, count($mountPointsOther));
 		$this->assertTrue(isset($mountPointsOther['/'.self::TEST_USER1.'/files/ext']));
-		$this->assertEquals('\OC\Files\Storage\SMB',
+		$this->assertEquals('Test_Mount_Config_Dummy_Storage',
 			$mountPointsOther['/'.self::TEST_USER1.'/files/ext']['class']);
 		$this->assertEquals($mountConfig,
 			$mountPointsOther['/'.self::TEST_USER1.'/files/ext']['options']);
@@ -1024,7 +1135,8 @@ class Test_Mount_Config extends \Test\TestCase {
 		$applicable = 'all';
 		$isPersonal = false;
 
-		$this->assertTrue(
+		$this->assertEquals(
+			0,
 			OC_Mount_Config::addMountPoint(
 				'/ext',
 				$storageClass,
