@@ -4,6 +4,12 @@ OC.L10N.register(
     "Cancel" : "Anullo",
     "Share" : "Ndaj",
     "Shared by" : "Ndarë nga",
+    "A file or folder has been <strong>shared</strong>" : "Një skedar ose dosje është <strong>ndarë</strong>",
+    "You shared %1$s with %2$s" : "Ju ndatë %1$s me %2$s",
+    "You shared %1$s with group %2$s" : "Ju ndatë %1$s me grupin %2$s",
+    "%2$s shared %1$s with you" : "%2$s ndau %1$s me ju",
+    "You shared %1$s via link" : "Ju ndatë %1$s me lidhje",
+    "Shares" : "ndarjet",
     "This share is password-protected" : "Kjo pjesë është e mbrojtur me fjalëkalim",
     "The password is wrong. Try again." : "Kodi është i gabuar. Provojeni përsëri.",
     "Password" : "Kodi",
