@@ -3,7 +3,7 @@ $TRANSLATIONS = array(
 "Pictures" => "Images",
 "Picture view" => "Visualisation de l'image",
 "Next" => "Suivant",
-"Play" => "Lire",
+"Play" => "Démarrer",
 "Pause" => "Pause",
 "Previous" => "Précédent",
 "Close" => "Fermer",
