@@ -1,11 +1,8 @@
 OC.L10N.register(
     "user_ldap",
     {
-    "Deletion failed" : "Konnt net läschen",
-    "Error" : "Fehler",
-    "_%s group found_::_%s groups found_" : ["",""],
-    "_%s user found_::_%s users found_" : ["",""],
-    "Save" : "Späicheren",
+    "Users" : "Benotzer",
+    "Groups" : "Gruppen",
     "Help" : "Hëllef",
     "Host" : "Host",
     "Password" : "Passwuert",
