@@ -4,16 +4,23 @@ OC.L10N.register(
     "Couldn't send mail to following users: %s " : "Kunne ikke sende mail til følgende brugere: %s",
     "Turned on maintenance mode" : "Startede vedligeholdelsestilstand",
     "Turned off maintenance mode" : "standsede vedligeholdelsestilstand",
+    "Maintenance mode is kept active" : "Vedligeholdelsestilstanden holdes kørende",
     "Updated database" : "Opdaterede database",
     "Checked database schema update" : "Tjekket database schema opdatering",
     "Checked database schema update for apps" : "Tjekkede databaseskemaets opdatering for apps",
     "Updated \"%s\" to %s" : "Opdaterede \"%s\" til %s",
-    "Disabled incompatible apps: %s" : "Deaktiverer inkompatible apps: %s",
+    "Repair warning: " : "Reparationsadvarsel:",
+    "Repair error: " : "Reparationsfejl:",
+    "Following incompatible apps have been disabled: %s" : "Følgende inkompatible apps er blevet deaktiveret: %s",
+    "Following 3rd party apps have been disabled: %s" : "Følgende apps fra 3. part er blevet deaktiveret: %s",
+    "Invalid file provided" : "Der er angivet en ugyldig fil",
     "No image or file provided" : "Ingen fil eller billede givet",
     "Unknown filetype" : "Ukendt filtype",
     "Invalid image" : "Ugyldigt billede",
     "No temporary profile picture available, try again" : "Intet midlertidigt profilbillede tilgængeligt, prøv igen",
     "No crop data provided" : "Ingen beskæringsdata give",
+    "No valid crop data provided" : "Der er ikke angivet gyldige data om beskæring",
+    "Crop is not square" : "Beskæringen er ikke kvadratisk",
     "Sunday" : "Søndag",
     "Monday" : "Mandag",
     "Tuesday" : "Tirsdag",
@@ -63,10 +70,15 @@ OC.L10N.register(
     "So-so password" : "Jævnt kodeord",
     "Good password" : "Godt kodeord",
     "Strong password" : "Stærkt kodeord",
-    "Your web server is not yet properly setup to allow files synchronization because the WebDAV interface seems to be broken." : "Din webserver er endnu ikke sat op til at tillade fil synkronisering fordi WebDAV grænsefladen virker ødelagt.",
-    "This server has no working internet connection. This means that some of the features like mounting of external storage, notifications about updates or installation of 3rd party apps don´t work. Accessing files from remote and sending of notification emails might also not work. We suggest to enable internet connection for this server if you want to have all features." : "Denne ownCloud-server har ikke en fungerende forbindelse til internettet. Det betyder, at visse funktioner som montering af eksterne drev, oplysninger om opdatering og installation af 3.-parts applikationer ikke fungerer. Det vil sandsynligvis heller ikke fungere at tilgå filer fra eksterne drev eller informations-e-mails. Vi opfordrer til at etablere forbindelse til internettet for denne server, såfremt du ønsker samtlige funktioner.",
-    "Your data directory and your files are probably accessible from the internet. The .htaccess file is not working. We strongly suggest that you configure your webserver in a way that the data directory is no longer accessible or you move the data directory outside the webserver document root." : "Din data mappe og dine filer er muligvis tilgængelige fra internettet. .htaccess filen virker ikke. Vi anbefaler på det kraftigste at du konfigurerer din webserver så data mappen ikke længere er tilgængelig, eller at du flytter data mappen uden for webserverens dokument rod.  ",
+    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Din webserver er endnu ikke sat korrekt op til at tillade filsynkronisering, fordi WebDAV-grænsefladen ser ud til at være i stykker.",
+    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Denne ownCloud-server har ikke en fungerende forbindelse til internettet. Det betyder, at visse funktioner som montering af eksterne drev, oplysninger om opdatering eller installation af applikationer fra tredjepart ikke fungerer. Det vil sandsynligvis heller ikke være muligt at tilgå filer fra eksterne drev eller afsendelse af e-mail med notifikationer virker sandsynligvis heller ikke. Vi opfordrer til at etablere forbindelse til internettet for denne server, såfremt du ønsker samtlige funktioner.",
+    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Din data mappe og dine filer er muligvis tilgængelige fra internettet. Filen .htaccess fungerer ikke. Vi anbefaler på det kraftigste, at du konfigurerer din webserver således at datamappen ikke længere er tilgængelig, eller at du flytter datamappen uden for webserverens dokumentrod.  ",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "Der er ikke konfigureret et hukommelsesmellemlager. For at forbedre din ydelse, skal du konfigurere et mellemlager, hvis den er tilgængelig. Du finder mere information i din <a href=\"{docLink}\">dokumentation</a>.",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "/dev/urandom kan ikke læses af PHP, hvilket stærkt frarådes af sikkerhedsmæssige årsager. Der fås mere information i vores <a href=\"{docLink}\">dokumentation</a>.",
     "Error occurred while checking server setup" : "Der opstod fejl under tjek af serveropsætningen",
+    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "HTTP-hovedet \"{header}\" er ikke konfigureret til at være lig med \"{expected}\". Dette er en potentiel sikkerhedsrisiko, og vi anbefaler at du justerer denne indstilling.",
+    "The \"Strict-Transport-Security\" HTTP header is not configured to least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "HTTP-hovedet \"Strict-Transport-Security\" er ikke konfigureret til mindst \"{seconds}\" sekunder. For udvidet sikkerhed anbefaler vi at aktivere HSTS, som foreskrevet i vores <a href=\"{docUrl}\">sikkerhedstips</a>.",
+    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Du tilgår dette sted gennem HTTP. Vi anbefaler kraftigt at du konfigurerer din server, så der kræves brug af HTTPS i stedet for, som foreskrevet i vores <a href=\"{docUrl}\">sikkerhedstips</a>.",
     "Shared" : "Delt",
     "Shared with {recipients}" : "Delt med {recipients}",
     "Share" : "Del",
@@ -76,7 +88,9 @@ OC.L10N.register(
     "Error while changing permissions" : "Fejl under justering af rettigheder",
     "Shared with you and the group {group} by {owner}" : "Delt med dig og gruppen {group} af {owner}",
     "Shared with you by {owner}" : "Delt med dig af {owner}",
-    "Share with user or group …" : "Del med bruger eller gruppe ...",
+    "Share with users or groups …" : "Del med brugere eller grupper",
+    "Share with users, groups or remote users …" : "Del med brugere, grupper eller eksterne brugere...",
+    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Del med andre på ownCloud ved hjælp af syntaxen username@example.com/owncloud",
     "Share link" : "Del link",
     "The public link will expire no later than {days} days after it is created" : "Det offentlige link udløber senest {days} dage efter det blev oprettet",
     "Link" : "Link",
@@ -89,6 +103,7 @@ OC.L10N.register(
     "Set expiration date" : "Vælg udløbsdato",
     "Expiration" : "Udløb",
     "Expiration date" : "Udløbsdato",
+    "An error occured. Please try again" : "Der skete en fejl. Prøv venligst igen",
     "Adding user..." : "Tilføjer bruger...",
     "group" : "gruppe",
     "remote" : "ekstern",
@@ -121,6 +136,7 @@ OC.L10N.register(
     "Hello {name}, the weather is {weather}" : "Hej {name}, vejret er {weather}",
     "Hello {name}" : "Hej {name}",
     "_download %n file_::_download %n files_" : ["hent %n fil","hent %n filer"],
+    "{version} is available. Get more information on how to update." : "{version} er tilgængelig. Få mere information om hvordan du opdaterer.",
     "Updating {productName} to version {version}, this may take a while." : "Opdaterer {productName} til version {version}, det kan tage et stykke tid.",
     "Please reload the page." : "Genindlæs venligst siden",
     "The update was unsuccessful. " : "Opdateringen blev ikke gennemført.",
@@ -134,14 +150,8 @@ OC.L10N.register(
     "New Password" : "Ny adgangskode",
     "Reset password" : "Nulstil kodeord",
     "Searching other places" : "Søger på andre steder",
-    "No search result in other places" : "Ingen søgeresultater fra andre steder",
+    "No search results in other places" : "Ingen søgeresultater fra andre steder",
     "_{count} search result in other places_::_{count} search results in other places_" : ["{count} søgeresultat fra andre steder","{count} søgeresultater fra andre steder"],
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X understøttes ikke og %s vil ikke virke optimalt på denne platform. Anvend på eget ansvar!",
-    "For the best results, please consider using a GNU/Linux server instead." : "For de bedste resultater, overvej venligst at bruge en GNU/Linux-server i stedet.",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4GB and is highly discouraged." : "Det ser ud til, at denne %s-instans kører på et 32-bit PHP-miljø, samt at open_basedir er blevet konfigureret gennem php.ini. Dette vil føre til problemer med filer som er større end 4GB, og frarådes kraftigt.",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Fjern venligst indstillingen for open_basedir inde i din php.ini eller skift til 64-bit PHP.",
-    "It seems that this %s instance is running on a 32-bit PHP environment and cURL is not installed. This will lead to problems with files over 4GB and is highly discouraged." : "Det ser ud til, at denne %s-instans kører på et 32-bit PHP-miljø, samt at cURL ikke er installeret. Dette vil føre til problemer med filer som er større end 4GB, og frarådes kraftigt.",
-    "Please install the cURL extension and restart your webserver." : "Installér venligst cURL-udvidelsen og genstart din webserver.",
     "Personal" : "Personligt",
     "Users" : "Brugere",
     "Apps" : "Apps",
@@ -168,14 +178,13 @@ OC.L10N.register(
     "Technical details" : "Tekniske detaljer",
     "Remote Address: %s" : "Fjernadresse: %s",
     "Request ID: %s" : "Forespørgsels-ID: %s",
+    "Type: %s" : "Indtast: %s",
     "Code: %s" : "Kode: %s",
     "Message: %s" : "Besked: %s",
     "File: %s" : "Fil: %s",
     "Line: %s" : "Linje: %s",
     "Trace" : "Sporing",
-    "Security Warning" : "Sikkerhedsadvarsel",
-    "Your PHP version is vulnerable to the NULL Byte attack (CVE-2006-7243)" : "Din PHP-version er sårbar overfor et NULL Byte angreb (CVE-2006-7243)",
-    "Please update your PHP installation to use %s securely." : "Opdater venligst din PHP installation for at anvende %s sikkert.",
+    "Security warning" : "Sikkerheds advarsel",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Dine data mappe og filer er sandsynligvis tilgængelige fra internettet fordi .htaccess filen ikke virker.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "For information om, hvordan du konfigurerer din server korrekt se <a href=\"%s\" target=\"_blank\">dokumentationen</a>.",
     "Create an <strong>admin account</strong>" : "Opret en <strong>administratorkonto</strong>",
@@ -184,19 +193,28 @@ OC.L10N.register(
     "Data folder" : "Datamappe",
     "Configure the database" : "Konfigurer databasen",
     "Only %s is available." : "Kun %s er tilgængelig.",
+    "Install and activate additional PHP modules to choose other database types." : "Installér og aktivér yderligere PHP-moduler for at vælge andre databasetyper.",
+    "For more details check out the documentation." : "For flere oplysninger, så henvises der til dokumentationen.",
     "Database user" : "Databasebruger",
     "Database password" : "Databasekodeord",
     "Database name" : "Navn på database",
     "Database tablespace" : "Database tabelplads",
     "Database host" : "Databasehost",
+    "Performance warning" : "Ydelses advarsel",
+    "SQLite will be used as database." : "SQLite vil blive brugt som database.",
+    "For larger installations we recommend to choose a different database backend." : "Til større installationer anbefaler vi at vælge en anden database-backend.",
+    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Brug af SQLite frarådes især når skrivebordsklienten anvendes til filsynkronisering.",
     "Finish setup" : "Afslut opsætning",
     "Finishing …" : "Færdigbehandler ...",
-    "This application requires JavaScript for correct operation. Please <a href=\"http://enable-javascript.com/\" target=\"_blank\">enable JavaScript</a> and reload the page." : "Applikationen kræver JavaScript for at fungere korrekt. <a href=\"http://enable-javascript.com/\" target=\"_blank\">Slå venligst JavaScript til</a> og genindlæs siden.",
-    "%s is available. Get more information on how to update." : "%s er tilgængelig. Få mere information om, hvordan du opdaterer.",
+    "Need help?" : "Brug for hjælp?",
+    "See the documentation" : "Se dokumentationen",
+    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Denne applikation kræver JavaScript for at fungere korrekt. {linkstart}Slå venligst JavaScript til{linkend} og genindlæs siden. ",
     "Log out" : "Log ud",
     "Search" : "Søg",
     "Server side authentication failed!" : "Server side godkendelse mislykkedes!",
     "Please contact your administrator." : "Kontakt venligst din administrator",
+    "An internal error occured." : "Der skete en intern fejl.",
+    "Please try again or contact your administrator." : "Kontakt venligst din administrator.",
     "Forgot your password? Reset it!" : "Glemt din adgangskode? Nulstil det!",
     "remember" : "husk",
     "Log in" : "Log ind",
@@ -216,7 +234,7 @@ OC.L10N.register(
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Sørg venligst for at sikre, at databasen, config-mappen og data-mappen er blevet sikkerhedskopieret inden vi fortsætter.",
     "Start update" : "Begynd opdatering",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "For at undgå tidsudløb ved større installationer, så kan du i stedet køre følgende kommando fra din installationsmappe:",
-    "This %s instance is currently being updated, which may take a while." : "Denne %s-instans bliver i øjeblikket opdateret, hvilket kan tage et stykke tid.",
+    "This %s instance is currently in maintenance mode, which may take a while." : "Denne %s-instans befinder sig i vedligeholdelsestilstand for øjeblikket, hvilket kan tage et stykke tid.",
     "This page will refresh itself when the %s instance is available again." : "Denne side vil genopfriske sig selv, når %s-instancen er tilgængelig igen."
 },
 "nplurals=2; plural=(n != 1);");
