@@ -8,12 +8,18 @@ OC.L10N.register(
     "Checked database schema update" : "Checked database schema update",
     "Checked database schema update for apps" : "Checked database schema update for apps",
     "Updated \"%s\" to %s" : "Updated \"%s\" to %s",
-    "Disabled incompatible apps: %s" : "Disabled incompatible apps: %s",
+    "Repair warning: " : "Repair warning: ",
+    "Repair error: " : "Repair error: ",
+    "Following incompatible apps have been disabled: %s" : "Following incompatible apps have been disabled: %s",
+    "Following 3rd party apps have been disabled: %s" : "Following 3rd party apps have been disabled: %s",
+    "Invalid file provided" : "Invalid file provided",
     "No image or file provided" : "No image or file provided",
     "Unknown filetype" : "Unknown filetype",
     "Invalid image" : "Invalid image",
     "No temporary profile picture available, try again" : "No temporary profile picture available, try again",
     "No crop data provided" : "No crop data provided",
+    "No valid crop data provided" : "No valid crop data provided",
+    "Crop is not square" : "Crop is not square",
     "Sunday" : "Sunday",
     "Monday" : "Monday",
     "Tuesday" : "Tuesday",
@@ -63,10 +69,13 @@ OC.L10N.register(
     "So-so password" : "So-so password",
     "Good password" : "Good password",
     "Strong password" : "Strong password",
-    "Your web server is not yet properly setup to allow files synchronization because the WebDAV interface seems to be broken." : "Your web server is not yet properly setup to allow files synchronisation because the WebDAV interface seems to be broken.",
-    "This server has no working internet connection. This means that some of the features like mounting of external storage, notifications about updates or installation of 3rd party apps don´t work. Accessing files from remote and sending of notification emails might also not work. We suggest to enable internet connection for this server if you want to have all features." : "This server has no working internet connection. This means that some of the features such as mounting external storage, notifications about updates, or installation of 3rd party apps won't work. Accessing files remotely and sending notification emails might also not work. We suggest enabling an internet connection for this server if you want to have all the features.",
-    "Your data directory and your files are probably accessible from the internet. The .htaccess file is not working. We strongly suggest that you configure your webserver in a way that the data directory is no longer accessible or you move the data directory outside the webserver document root." : "Your data directory and your files are probably accessible from the internet. The .htaccess file is not working. We strongly suggest that you configure your webserver in a way that the data directory is no longer accessible or you move the data directory outside the webserver document root.",
+    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Your web server is not yet set up properly to allow file synchronisation because the WebDAV interface seems to be broken.",
+    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest enabling the Internet connection for this server.",
+    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root.",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a href=\"{docLink}\">documentation</a>.",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a href=\"{docLink}\">documentation</a>.",
     "Error occurred while checking server setup" : "Error occurred whilst checking server setup",
+    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting.",
     "Shared" : "Shared",
     "Shared with {recipients}" : "Shared with {recipients}",
     "Share" : "Share",
@@ -76,7 +85,9 @@ OC.L10N.register(
     "Error while changing permissions" : "Error whilst changing permissions",
     "Shared with you and the group {group} by {owner}" : "Shared with you and the group {group} by {owner}",
     "Shared with you by {owner}" : "Shared with you by {owner}",
-    "Share with user or group …" : "Share with user or group …",
+    "Share with users or groups …" : "Share with users or groups …",
+    "Share with users, groups or remote users …" : "Share with users, groups or remote users …",
+    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Share with people on other ownClouds using the syntax username@example.com/owncloud",
     "Share link" : "Share link",
     "The public link will expire no later than {days} days after it is created" : "The public link will expire no later than {days} days after it is created",
     "Link" : "Link",
@@ -89,6 +100,7 @@ OC.L10N.register(
     "Set expiration date" : "Set expiration date",
     "Expiration" : "Expiration",
     "Expiration date" : "Expiration date",
+    "An error occured. Please try again" : "An error occured. Please try again",
     "Adding user..." : "Adding user...",
     "group" : "group",
     "remote" : "remote",
@@ -121,6 +133,7 @@ OC.L10N.register(
     "Hello {name}, the weather is {weather}" : "Hello {name}, the weather is {weather}",
     "Hello {name}" : "Hello {name}",
     "_download %n file_::_download %n files_" : ["download %n file","download %n files"],
+    "{version} is available. Get more information on how to update." : "{version} is available. Get more information on how to update.",
     "Updating {productName} to version {version}, this may take a while." : "Updating {productName} to version {version}, this may take a while.",
     "Please reload the page." : "Please reload the page.",
     "The update was unsuccessful. " : "The update was unsuccessful. ",
@@ -134,14 +147,8 @@ OC.L10N.register(
     "New Password" : "New Password",
     "Reset password" : "Reset password",
     "Searching other places" : "Searching other places",
-    "No search result in other places" : "No search result in other places",
+    "No search results in other places" : "No search results in other places",
     "_{count} search result in other places_::_{count} search results in other places_" : ["{count} search result in other places","{count} search results in other places"],
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! ",
-    "For the best results, please consider using a GNU/Linux server instead." : "For the best results, please consider using a GNU/Linux server instead.",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4GB and is highly discouraged." : "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4GB and is highly discouraged.",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP.",
-    "It seems that this %s instance is running on a 32-bit PHP environment and cURL is not installed. This will lead to problems with files over 4GB and is highly discouraged." : "It seems that this %s instance is running on a 32-bit PHP environment and cURL is not installed. This will lead to problems with files over 4GB and is highly discouraged.",
-    "Please install the cURL extension and restart your webserver." : "Please install the cURL extension and restart your webserver.",
     "Personal" : "Personal",
     "Users" : "Users",
     "Apps" : "Apps",
@@ -168,14 +175,13 @@ OC.L10N.register(
     "Technical details" : "Technical details",
     "Remote Address: %s" : "Remote Address: %s",
     "Request ID: %s" : "Request ID: %s",
+    "Type: %s" : "Type: %s",
     "Code: %s" : "Code: %s",
     "Message: %s" : "Message: %s",
     "File: %s" : "File: %s",
     "Line: %s" : "Line: %s",
     "Trace" : "Trace",
-    "Security Warning" : "Security Warning",
-    "Your PHP version is vulnerable to the NULL Byte attack (CVE-2006-7243)" : "Your PHP version is vulnerable to the NULL Byte attack (CVE-2006-7243)",
-    "Please update your PHP installation to use %s securely." : "Please update your PHP installation to use %s securely.",
+    "Security warning" : "Security warning",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Your data directory and files are probably accessible from the internet because the .htaccess file does not work.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>.",
     "Create an <strong>admin account</strong>" : "Create an <strong>admin account</strong>",
@@ -184,19 +190,28 @@ OC.L10N.register(
     "Data folder" : "Data folder",
     "Configure the database" : "Configure the database",
     "Only %s is available." : "Only %s is available.",
+    "Install and activate additional PHP modules to choose other database types." : "Install and activate additional PHP modules to choose other database types.",
+    "For more details check out the documentation." : "For more details check out the documentation.",
     "Database user" : "Database user",
     "Database password" : "Database password",
     "Database name" : "Database name",
     "Database tablespace" : "Database tablespace",
     "Database host" : "Database host",
+    "Performance warning" : "Performance warning",
+    "SQLite will be used as database." : "SQLite will be used as database.",
+    "For larger installations we recommend to choose a different database backend." : "For larger installations we recommend to choose a different database backend.",
+    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Especially when using the desktop client for file syncing, the use of SQLite is discouraged.",
     "Finish setup" : "Finish setup",
     "Finishing …" : "Finishing …",
-    "This application requires JavaScript for correct operation. Please <a href=\"http://enable-javascript.com/\" target=\"_blank\">enable JavaScript</a> and reload the page." : "This application requires JavaScript for correct operation. Please <a href=\"http://enable-javascript.com/\" target=\"_blank\">enable JavaScript</a> and reload the page.",
-    "%s is available. Get more information on how to update." : "%s is available. Get more information on how to update.",
+    "Need help?" : "Need help?",
+    "See the documentation" : "See the documentation",
+    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page.",
     "Log out" : "Log out",
     "Search" : "Search",
     "Server side authentication failed!" : "Server side authentication failed!",
     "Please contact your administrator." : "Please contact your administrator.",
+    "An internal error occured." : "An internal error occured.",
+    "Please try again or contact your administrator." : "Please try again or contact your administrator.",
     "Forgot your password? Reset it!" : "Forgot your password? Reset it!",
     "remember" : "remember",
     "Log in" : "Log in",
@@ -216,7 +231,7 @@ OC.L10N.register(
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Please make sure that the database, the config folder and the data folder have been backed up before proceeding.",
     "Start update" : "Start update",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:",
-    "This %s instance is currently being updated, which may take a while." : "This %s instance is currently being updated, which may take a while.",
+    "This %s instance is currently in maintenance mode, which may take a while." : "This %s instance is currently in maintenance mode, which may take a while.",
     "This page will refresh itself when the %s instance is available again." : "This page will refresh itself when the %s instance is available again."
 },
 "nplurals=2; plural=(n != 1);");
