@@ -8,7 +8,6 @@ OC.L10N.register(
     "Checked database schema update" : "﻿ಪರಿಶೀಲಿಸಿದ ದತ್ತಸಂಚಯ ಯೋಜನಾ ಅಪ್ಡೇಟ್",
     "Checked database schema update for apps" : "ನವೀಕರಿಸಿದ ದತ್ತಸಂಚಯದ ಯೋಜನಾ ಪ್ರತಿಗಳನ್ನು ಕಾಯಕ್ರಮಗಳೊಂದಿಗೆ ಪರಿಶೀಲಿಸಲಾಗಿದೆ",
     "Updated \"%s\" to %s" : "﻿%s ರ ಆವೃತ್ತಿ %s ನ್ನು ನವೀಕರಿಸಲಾಗುತ್ತದೆ.",
-    "Disabled incompatible apps: %s" : "ಹೊಂದಾಣಿಕೆಯಾಗದ %s ಅಪ್ಲಿಕೇಶನ್ಗಳನ್ನು ನಿಷ್ಕ್ರಿಯಗೊಳಿಸಲಾಗಿದೆ",
     "No image or file provided" : "ಚಿತ್ರ ಅಥವಾ ಕಡತದ ಕೊರತೆ ಇದೆ",
     "Unknown filetype" : "﻿ಅಪರಿಚಿತ ಕಡತ ಮಾದರಿ",
     "Invalid image" : "ಅಸಾಮರ್ಥ್ಯ ಚಿತ್ರ",
@@ -45,7 +44,6 @@ OC.L10N.register(
     "Choose" : "﻿ಆಯ್ಕೆ",
     "Ok" : "﻿ಸರಿ",
     "read-only" : "﻿ಓದಲು ಮಾತ್ರ",
-    "_{count} file conflict_::_{count} file conflicts_" : [""],
     "One file conflict" : "﻿ಒಂದು ಕಡತದಲ್ಲಿ ಸಮಸ್ಯೆ ಇದೆ",
     "New Files" : "ಹೊಸ ಕಡತಗಳು",
     "Already existing files" : "﻿ಈಗಾಗಲೇ ಅಸ್ತಿತ್ವದಲ್ಲಿರುವ ಕಡತಗಳು",
@@ -70,7 +68,6 @@ OC.L10N.register(
     "Error while changing permissions" : "ಅನುಮತಿಗಳನ್ನು ಬದಲಾವಣೆ ಮಾಡುವಾಗ ದೋಷವಾಗಿದೆ",
     "Shared with you and the group {group} by {owner}" : "ನಿಮಗೆ ಮತ್ತು {group} ಗುಂಪಿನೂಂದಿಗೆ {owner} ಹಂಚಿಕೊಂಡಿದ್ದಾರೆ",
     "Shared with you by {owner}" : "﻿ನಿಮ್ಮೊಂದಿಗೆ {owner} ಹಂಚಿಕೊಂಡಿದ್ದಾರೆ",
-    "Share with user or group …" : "﻿ಬಳಕೆದಾರ ಅಥವಾ ಗುಂಪನ್ನು ಜೊತೆ ಹಂಚಿಕೊಳ್ಳಿ ...",
     "Share link" : "ಸಂಪರ್ಕ ಕೊಂಡಿಯನ್ನು  ﻿ಹಂಚಿಕೊಳ್ಳಬಹುದು",
     "The public link will expire no later than {days} days after it is created" : "﻿ರಚನೆಯಾದ {days} ದಿನಗಳ ನಂತರ ಈ ಸಾರ್ವಜನಿಕ ಸಂಪರ್ಕ ಕೊಂಡಿ ಅಂತ್ಯಗೊಳ್ಳಲಿದೆ",
     "Link" : "ಸಂಪರ್ಕ ಕೊಂಡಿ",
@@ -123,7 +120,6 @@ OC.L10N.register(
     "New password" : "﻿ಹೊಸ ಗುಪ್ತಪದ",
     "New Password" : "ಹೊಸ ಗುಪ್ತಪದ",
     "Reset password" : "ಗುಪ್ತ ಪದವನ್ನು ಮರುಹೊಂದಿಸಿ",
-    "_{count} search result in other places_::_{count} search results in other places_" : [""],
     "Personal" : "﻿ವೈಯಕ್ತಿಕ",
     "Users" : "﻿ಬಳಕೆದಾರರು",
     "Apps" : "ಕಾರ್ಯಕ್ರಮಗಳು",
@@ -149,7 +145,6 @@ OC.L10N.register(
     "File: %s" : "ಕಡತ: %s",
     "Line: %s" : "ಕೋಂಡಿ: %s",
     "Trace" : "ಕುರುಹು",
-    "Security Warning" : "﻿ಭದ್ರತಾ ಎಚ್ಚರಿಕೆ",
     "Username" : "﻿ಬಳಕೆಯ ಹೆಸರು",
     "Storage & database" : "ಶೇಖರಣಾ ಮತ್ತು ದತ್ತಸಂಚಯ",
     "Data folder" : "﻿ಮಾಹಿತಿ ಕೋಶ",
@@ -162,7 +157,6 @@ OC.L10N.register(
     "Database host" : "ದತ್ತಸಂಚಯದ ಅತಿಥೆಯ",
     "Finish setup" : "ಹೊಂದಾಣಿಕೆಗಳನ್ನು ಪೂರ್ಣಗೊಳಿಸಿ",
     "Finishing …" : "ಪೂರ್ಣಗೊಳಿಸಲಾಗುತ್ತಿದೆ ...",
-    "%s is available. Get more information on how to update." : "%s ಲಭ್ಯವಿದೆ.  ಹೇಗೆ ನವೀಕರಿಸಬಹುದೆಂದು ಹೆಚ್ಚಿನ ಮಾಹಿತಿಯನ್ನು ಪಡೆಯಿರಿ.",
     "Log out" : "ಈ ಆವೃತ್ತಿ ಇಂದ ನಿರ್ಗಮಿಸಿ",
     "Search" : "﻿ಹುಡುಕು",
     "Please contact your administrator." : "ನಿಮ್ಮ ನಿರ್ವಾಹಕರನ್ನು ಸಂಪರ್ಕಿಸಲು ಕೋರಲಾಗಿದೆ.",
