@@ -19,12 +19,9 @@ OC.L10N.register(
     "ownCloud with a version lower than %s is required." : "Необходим е ownCloud с по-ниска версия от %s.",
     "Help" : "Помощ",
     "Personal" : "Лични",
-    "Settings" : "Настройки",
     "Users" : "Потребители",
     "Admin" : "Админ",
     "Recommended" : "Препоръчано",
-    "App \\\"%s\\\" can't be installed because it is not compatible with this version of ownCloud." : "Приложението \\\"%s\\\" не може да бъде инсталирано, защото не е съвместимо с тази версия на ownCloud.",
-    "App \\\"%s\\\" cannot be installed because the following dependencies are not fulfilled: %s" : "Приложението \\\"%s\\\" не може да бъде инсталирано, защот следните зависимости не са удовлетворени: %s",
     "No app name specified" : "Не е зададено име на преложението",
     "Unknown filetype" : "Непознат тип файл.",
     "Invalid image" : "Невалидно изображение.",
@@ -32,14 +29,9 @@ OC.L10N.register(
     "yesterday" : "вчера",
     "_%n day ago_::_%n days ago_" : ["преди %n ден","преди %n дни"],
     "last month" : "миналия месец",
-    "_%n month ago_::_%n months ago_" : ["","преди %n месеца"],
     "last year" : "миналата година",
     "_%n year ago_::_%n years ago_" : ["преди %n година","преди %n години"],
-    "_%n hour ago_::_%n hours ago_" : ["","преди %n часа"],
-    "_%n minute ago_::_%n minutes ago_" : ["","преди %n минути"],
     "seconds ago" : "преди секунди",
-    "Database Error" : "Грешка в базата данни",
-    "Please contact your system administrator." : "Моля, свържи се с админстратора.",
     "web services under your control" : "уеб услуги под твой контрол",
     "App directory already exists" : "Папката на приложението вече съществува.",
     "Can't create app folder. Please fix permissions. %s" : "Неуспешно създаване на папката за приложението. Моля, оправете разрешенията. %s",
@@ -73,6 +65,9 @@ OC.L10N.register(
     "Oracle username and/or password not valid" : "Невалидно Oracle потребителско име и/или парола.",
     "Offending command was: \"%s\", name: %s, password: %s" : "Проблемната команда беше: \"%s\", име: %s, парола: %s.",
     "PostgreSQL username and/or password not valid" : "Невалидно PostgreSQL потребителско име и/или парола.",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X не се подържа и %s няма да работи правилно на тази платформа. Използвайте го на свой собствен риск!",
+    "For the best results, please consider using a GNU/Linux server instead." : "За най-добри резултати, моля, помисли дали не бихте желали да използваште GNU/Linux сървър.",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Моля, премахтене настройката за open_basedir от вашия php.ini или преминете към 64-битово PHP.",
     "Set an admin username." : "Задай потребителско име за администратор.",
     "Set an admin password." : "Задай парола за администратор.",
     "Can't create or write into the data directory %s" : "Неуспешно създаване или записване в \"data\" папката %s",
@@ -108,20 +103,16 @@ OC.L10N.register(
     "A valid password must be provided" : "Валидна парола трябва да бъде зададена.",
     "The username is already being used" : "Това потребителско име е вече заето.",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Липсват инсталирани драйвери за бази данни(sqlite, mysql или postgresql).",
-    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Правата за достъп обикновено могат да бъдат оправени като %s даде разрешение на уеб сървъра да пише в root папката %s.",
     "Cannot write into \"config\" directory" : "Неуспешен опит за запис в \"config\" папката.",
     "Cannot write into \"apps\" directory" : "Неуспешен опит за запис в \"apps\" папката.",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Това обикновено може да бъде оправено като %s даде разрешение на уеб сървъра да записва в app папката %s или като изключи магазина за приложения в config файла.",
     "Cannot create \"data\" directory (%s)" : "Неуспешен опит за създаване на \"data\" папката (%s).",
     "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Това обикновено може да бъде оправено като <a href=\"%s\" target=\"_blank\">дадеш разрешение на уеб сървъра да записва в root  папката</a>.",
+    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Правата за достъп обикновено могат да бъдат оправени като %s даде разрешение на уеб сървъра да пише в root папката %s.",
     "Setting locale to %s failed" : "Неуспешно задаване на %s като настройка език-държава.",
     "Please install one of these locales on your system and restart your webserver." : "Моля, инсталирай едно от следните език-държава на сървъра и рестартирай уеб сървъра.",
     "Please ask your server administrator to install the module." : "Моля, поискай твоят администратор да инсталира модула.",
     "PHP module %s not installed." : "PHP модулът %s не е инсталиран.",
-    "Please ask your server administrator to update PHP to the latest version. Your PHP version is no longer supported by ownCloud and the PHP community." : "Моля, поискай твоят администратор да обнови PHP до най-новата верския. Твоята PHP версия вече не се поддържа от ownCloud и PHP общността.",
-    "PHP is configured to populate raw post data. Since PHP 5.6 this will lead to PHP throwing notices for perfectly valid code." : "PHP е конфигуриран да запълва post данните от ниско ниво. От PHP 5.6 насам това води до връщането на грешки при абсолютно валиден код.",
-    "To fix this issue set <code>always_populate_raw_post_data</code> to <code>-1</code> in your php.ini" : "За да поправите този проблем, задайте на <code>always_populate_raw_post_data</code> стойност <code>-1</code> във вашоя php.ini",
-    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP е настроен да премахва inline doc блокове. Това може да превърне няколко основни приложения недостъпни.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Това може да се дължи на cache/accelerator като Zend OPache или eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP модулите са инсталирани, но все още се обявяват като липсващи?",
     "Please ask your server administrator to restart the web server." : "Моля, поискай от своя администратор да рестартира уеб сървъра.",
