@@ -3,21 +3,16 @@ OC.L10N.register(
     {
     "Help" : "Pomoć",
     "Personal" : "Osobno",
-    "Settings" : "Postavke",
     "Users" : "Korisnici",
     "Admin" : "Admin",
     "Recommended" : "Preporučljivo",
     "Unknown filetype" : "Nepoznat tip datoteke",
     "Invalid image" : "Nevažeća datoteka",
-    "_%n day ago_::_%n days ago_" : ["","",""],
-    "_%n month ago_::_%n months ago_" : ["","",""],
-    "_%n year ago_::_%n years ago_" : ["","",""],
-    "_%n hour ago_::_%n hours ago_" : ["","",""],
-    "_%n minute ago_::_%n minutes ago_" : ["","",""],
     "Authentication error" : "Grešna autentifikacije",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nije podržan i %s na ovoj platformi neće raditi kako treba. Korištenje na vlastiti rizik!",
+    "For the best results, please consider using a GNU/Linux server instead." : "Umjesto toga, za najbolje rezultate, molimo razmislite o mogućnosti korištenje GNU/Linux servera.",
     "A valid username must be provided" : "Nužno je navesti valjano korisničko ime",
     "A valid password must be provided" : "Nužno je navesti valjanu lozinku",
-    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP je očigledno postavljen da se skine inline doc blokova. To će nekoliko osnovnih aplikacija učiniti nedostupnim.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Uzrok tome je vjerojatno neki ubrzivač predmemorisanja kao što je Zend OPcache ili eAccelerator."
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
