@@ -19,12 +19,11 @@ OC.L10N.register(
     "ownCloud with a version lower than %s is required." : "Requírese ownCloud cunha versión inferior a %s.",
     "Help" : "Axuda",
     "Personal" : "Persoal",
-    "Settings" : "Axustes",
     "Users" : "Usuarios",
     "Admin" : "Administración",
     "Recommended" : "Recomendado",
-    "App \\\"%s\\\" can't be installed because it is not compatible with this version of ownCloud." : "Non é posíbel instalar a aplicación «%s» por non seren compatíbel con esta versión do ownCloud.",
-    "App \\\"%s\\\" cannot be installed because the following dependencies are not fulfilled: %s" : "Non é posíbel instalar a aplicación «%s» por mor de non cumprirse as dependencias: %s",
+    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "Non é posíbel instalar a aplicación «%s» por non seren compatíbel con esta versión do ownCloud.",
+    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Non é posíbel instalar a aplicación «%s» por mor de non cumprirse as dependencias: %s",
     "No app name specified" : "Non se especificou o nome da aplicación",
     "Unknown filetype" : "Tipo de ficheiro descoñecido",
     "Invalid image" : "Imaxe incorrecta",
@@ -38,14 +37,21 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["hai %n hora","hai %n horas"],
     "_%n minute ago_::_%n minutes ago_" : ["hai %n minuto","hai %n minutos"],
     "seconds ago" : "segundos atrás",
-    "Database Error" : "Produciuse un erro na base de datos",
-    "Please contact your system administrator." : "Contacte co administrador.",
     "web services under your control" : "servizos web baixo o seu control",
+    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Non existe o módulo co ID: %s. Actíveo nos axustes das aplicacións ou contacte co administrador.",
+    "Empty filename is not allowed" : "Non está permitido deixar baleiro o nome de ficheiro",
+    "Dot files are not allowed" : "Non se admiten os ficheiros con punto",
+    "4-byte characters are not supported in file names" : "Non se admiten os caracteres de 4 bytes nos nomes de ficheiro",
+    "File name is a reserved word" : "O nome de ficheiro é unha palabra reservada",
+    "File name contains at least one invalid character" : "O nome de ficheiro contén algún carácter incorrecto",
+    "File name is too long" : "O nome de ficheiro é longo de máis",
+    "File is currently busy, please try again later" : "O ficheiro está ocupado neste momento, tenteo máis tarde.",
+    "Can't read file" : "Non é posíbel ler o ficheiro",
     "App directory already exists" : "Xa existe o directorio da aplicación",
     "Can't create app folder. Please fix permissions. %s" : "Non é posíbel crear o cartafol de aplicacións. Corrixa os permisos. %s",
-    "No source specified when installing app" : "Non foi especificada ningunha orixe ao instalar aplicacións",
-    "No href specified when installing app from http" : "Non foi especificada ningunha href ao instalar aplicacións",
-    "No path specified when installing app from local file" : "Non foi especificada ningunha ruta ao instalar aplicacións desde un ficheiro local",
+    "No source specified when installing app" : "Non foi especificada ningunha orixe ao instalar a aplicación",
+    "No href specified when installing app from http" : "Non foi especificada ningunha «href» ao instalar a aplicación",
+    "No path specified when installing app from local file" : "Non foi especificada ningunha ruta ao instalar a aplicación desde un ficheiro local",
     "Archives of type %s are not supported" : "Os arquivos do tipo %s non están admitidos",
     "Failed to open archive when installing app" : "Non foi posíbel abrir o arquivo ao instalar aplicacións",
     "App does not provide an info.xml file" : "A aplicación non fornece un ficheiro info.xml",
@@ -73,10 +79,16 @@ OC.L10N.register(
     "Oracle username and/or password not valid" : "O nome de usuario e/ou contrasinal de Oracle é incorrecto",
     "Offending command was: \"%s\", name: %s, password: %s" : "A orde infractora foi: «%s», nome: %s, contrasinal: %s",
     "PostgreSQL username and/or password not valid" : "Nome de usuario e/ou contrasinal de PostgreSQL incorrecto",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X non é compatíbel e %s non funcionará correctamente nesta plataforma. Utilíceo baixo a  súa responsabilidade!",
+    "For the best results, please consider using a GNU/Linux server instead." : "Para obter mellores resultados, considere o emprego dun servidor GNU/Linux no seu canto.",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Semella que esta instancia de %s está a funcionar nun entorno PHP de 32 bisst e o open_basedir foi configurado no php.ini. Isto provocará problemas con ficheiros maiores de 4 GB e está absolutamente desaconsellado.",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Retire o axuste de open_basedir no php.ini ou cambie a PHP de 64 bits.",
     "Set an admin username." : "Estabeleza un nome de usuario administrador",
     "Set an admin password." : "Estabeleza un contrasinal de administrador",
     "Can't create or write into the data directory %s" : "Non é posíbel crear ou escribir o directorio «data» %s",
+    "Invalid Federated Cloud ID" : "ID de nube federada incorrecto",
     "%s shared »%s« with you" : "%s compartiu «%s» con vostede",
+    "%s via %s" : "%s vía %s",
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Fallou a compartición de %s, xa que a infraestrutura non permite accións do tipo %i",
     "Sharing %s failed, because the file does not exist" : "Fallou a compartición de %s, o ficheiro non existe",
     "You are not allowed to share %s" : "Non ten permiso para compartir %s",
@@ -94,6 +106,7 @@ OC.L10N.register(
     "Setting permissions for %s failed, because the item was not found" : "Non é posíbel estabelecer permisos para %s, non se atopa o elemento",
     "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Non é posíbel estabelecer a data de caducidade. As comparticións non poden caducar máis aló de %s após de seren compartidas",
     "Cannot set expiration date. Expiration date is in the past" : "Non é posíbel estabelecer a data de caducidade. A data de caducidade está no pasado.",
+    "Cannot clear expiration date. Shares are required to have an expiration date." : "Non é posíbel limpar a data de caducidade. É necesaria algunha compartición para ter unha data de caducidade.",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "A infraestrutura de compartición %s ten que implementar a interface OCP\\Share_Backend",
     "Sharing backend %s not found" : "Non se atopou a infraestrutura de compartición %s",
     "Sharing backend for %s not found" : "Non se atopou a infraestrutura de compartición para %s",
@@ -108,20 +121,23 @@ OC.L10N.register(
     "A valid password must be provided" : "Debe fornecer un contrasinal",
     "The username is already being used" : "Este nome de usuario xa está a ser usado",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Non hay controladores de base de datos (sqlite, mysql, ou postgresql) instalados.",
-    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Polo xeral, isto pode ser fixado para %spermitirlle ao servidor web acceso de escritura  ao directorio «root»%s.",
+    "Microsoft Windows Platform is not supported" : "A plataforma Windows de Microsoft non é compatíbel",
+    "Running ownCloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "Non é posíbel a execución dun servidor ownCloud na plataforma Microsoft Windows. Se non ten a opción de migrar o propio servidor, suxerímoslle que empregue un servidor Linux nunha máquina virtual. Pode atopar paquetes de Linux, así como imaxes de máquinas virtuais doadas de instalar en <a href=\"%s\">%s</a>. Para a migración das instalacións existentes cara Linux pode atopar algúns consellos e un script de migración na <a href=\"%s\">nosa documentación</a>.",
     "Cannot write into \"config\" directory" : "Non é posíbel escribir no directorio «config»",
     "Cannot write into \"apps\" directory" : "Non é posíbel escribir no directorio «apps»",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Polo xeral, isto pode ser fixado para %spermitirlle ao servidor web acceso de escritura  ao directorio «apps»%s ou a desactivación da «appstore» no ficheiro de configuración.",
     "Cannot create \"data\" directory (%s)" : "Non é posíbel crear o directorio «data» (%s)",
     "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Polo xeral, isto pode ser fixado para <a href=\"%s\" target=\"_blank\">permitirlle ao servidor web acceso de escritura  ao directorio «root»</a>.",
+    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Polo xeral, isto pode ser fixado para %spermitirlle ao servidor web acceso de escritura  ao directorio «root»%s.",
     "Setting locale to %s failed" : "Fallou o axuste da configuración local a %s",
     "Please install one of these locales on your system and restart your webserver." : "Instale unha destas configuracións locais no seu sistema e reinicie o servidor web.",
     "Please ask your server administrator to install the module." : "Pregúntelle ao administrador do servidor pola instalación do módulo.",
     "PHP module %s not installed." : "O módulo PHP %s non está instalado.",
-    "Please ask your server administrator to update PHP to the latest version. Your PHP version is no longer supported by ownCloud and the PHP community." : "Pregúntelle ao administrador do servidor pola actualización de PHP á versión máis recente. A súa versión de PHP xa non é asistida polas comunidades de ownCloud e PHP.",
-    "PHP is configured to populate raw post data. Since PHP 5.6 this will lead to PHP throwing notices for perfectly valid code." : "PHP está configurado para surtir datos de código en bruto. Desde PHP 5.6 esto levará a que PHP proporcione avisos con código perfectamente válido.",
-    "To fix this issue set <code>always_populate_raw_post_data</code> to <code>-1</code> in your php.ini" : "Para solucionar este asunto estableza <code>always_populate_raw_post_data</code> a <code>-1</code> no seu php.ini",
-    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "Parece que PHP foi configuración para substituír bloques de documentos en liña. Isto fará que varias aplicacións sexan inaccesíbeis.",
+    "PHP setting \"%s\" is not set to \"%s\"." : "O axuste de PHP «%s» non está estabelecido a «%s».",
+    "Adjusting this setting in php.ini will make ownCloud run again" : "Facer este axuste en php.ini fará que ownCloud volva executarse",
+    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload está estabelecido a «%s» no canto do valor «0» agardado",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Para arranxar este problema, estabeleza <code>mbstring.func_overload</code> a <code>0</code> no ficheiro php.ini",
+    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Semella que PHP foi configurado para quitar bloques de documentos en liña. Isto fará que varias aplicacións sexan inaccesíbeis.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Isto probabelmente se debe unha caché/acelerador como Zend OPcache ou eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Instaláronse os módulos de PHP, mais aínda aparecen listados como perdidos?",
     "Please ask your server administrator to restart the web server." : "Pregúntelle ao administrador do servidor polo reinicio do servidor web..",
@@ -131,6 +147,8 @@ OC.L10N.register(
     "Please make sure you have PostgreSQL >= 9 or check the logs for more information about the error" : "Asegúrese de que dispón do PostgreSQL >= 9 ou comprobe os rexistros para obter máis información sobre este erro",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Cambie os permisos a 0770 para que o directorio non poida seren listado por outros usuarios.",
     "Data directory (%s) is readable by other users" : "O directorio de datos (%s) é lexíbel por outros usuarios",
+    "Data directory (%s) must be an absolute path" : "O directorio de datos (%s) debe ser unha ruta absoluta",
+    "Check the value of \"datadirectory\" in your configuration" : "Comprobe o valor de «datadirectory» na configuración",
     "Data directory (%s) is invalid" : "O directorio de datos (%s) non é correcto",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Comprobe que o directorio de datos conten un ficheiro «.ocdata» na súa raíz.",
     "Could not obtain lock type %d on \"%s\"." : "Non foi posíbel obter un bloqueo do tipo %d en «%s»."
