@@ -3,20 +3,14 @@ OC.L10N.register(
     {
     "Help" : "Hjelp",
     "Personal" : "Personleg",
-    "Settings" : "Innstillingar",
     "Users" : "Brukarar",
     "Admin" : "Administrer",
     "Unknown filetype" : "Ukjend filtype",
     "Invalid image" : "Ugyldig bilete",
     "today" : "i dag",
     "yesterday" : "i går",
-    "_%n day ago_::_%n days ago_" : ["",""],
     "last month" : "førre månad",
-    "_%n month ago_::_%n months ago_" : ["","%n månadar sidan"],
     "last year" : "i fjor",
-    "_%n year ago_::_%n years ago_" : ["",""],
-    "_%n hour ago_::_%n hours ago_" : ["","%n timar sidan"],
-    "_%n minute ago_::_%n minutes ago_" : ["","%n minutt sidan"],
     "seconds ago" : "sekund sidan",
     "web services under your control" : "Vev tjenester under din kontroll",
     "Authentication error" : "Feil i autentisering",
