@@ -3,18 +3,12 @@ OC.L10N.register(
     {
     "Help" : "உதவி",
     "Personal" : "தனிப்பட்ட",
-    "Settings" : "அமைப்புகள்",
     "Users" : "பயனாளர்",
     "Admin" : "நிர்வாகம்",
     "today" : "இன்று",
     "yesterday" : "நேற்று",
-    "_%n day ago_::_%n days ago_" : ["",""],
     "last month" : "கடந்த மாதம்",
-    "_%n month ago_::_%n months ago_" : ["",""],
     "last year" : "கடந்த வருடம்",
-    "_%n year ago_::_%n years ago_" : ["",""],
-    "_%n hour ago_::_%n hours ago_" : ["",""],
-    "_%n minute ago_::_%n minutes ago_" : ["",""],
     "seconds ago" : "செக்கன்களுக்கு முன்",
     "web services under your control" : "வலைய சேவைகள் உங்களுடைய கட்டுப்பாட்டின் கீழ் உள்ளது",
     "Application is not enabled" : "செயலி இயலுமைப்படுத்தப்படவில்லை",
