@@ -1,22 +1,30 @@
 <?php
 /**
- * ownCloud
+ * @author Bart Visscher <bartv@thisnet.nl>
+ * @author Dan Bartram <daneybartram@gmail.com>
+ * @author Felix Moeller <mail@felixmoeller.de>
+ * @author Frank Karlitschek <frank@owncloud.org>
+ * @author Joas Schilling <nickvergessen@owncloud.com>
+ * @author Jörn Friedrich Dreyer <jfd@butonic.de>
+ * @author Morris Jobke <hey@morrisjobke.de>
+ * @author Robin Appelman <icewind@owncloud.com>
+ * @author Thomas Müller <thomas.mueller@tmit.eu>
+ * @author Thomas Tanghus <thomas@tanghus.net>
  *
- * @author Frank Karlitschek
- * @copyright 2012 Frank Karlitschek frank@owncloud.org
+ * @copyright Copyright (c) 2015, ownCloud, Inc.
+ * @license AGPL-3.0
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU AFFERO GENERAL PUBLIC LICENSE
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or any later version.
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3,
+ * as published by the Free Software Foundation.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU AFFERO GENERAL PUBLIC LICENSE for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
  *
- * You should have received a copy of the GNU Affero General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU Affero General Public License, version 3,
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>
  *
  */
 
@@ -32,6 +40,8 @@ namespace OCP;
 
 /**
  * This class provides access to the internal database system. Use this class exlusively if you want to access databases
+ * @deprecated 8.1.0 use methods of \OCP\IDBConnection - \OC::$server->getDatabaseConnection()
+ * @since 4.5.0
  */
 class DB {
 	/**
@@ -42,6 +52,8 @@ class DB {
 	 * @return \OC_DB_StatementWrapper prepared SQL query
 	 *
 	 * SQL query via Doctrine prepare(), needs to be execute()'d!
+	 * @deprecated 8.1.0 use prepare() of \OCP\IDBConnection - \OC::$server->getDatabaseConnection()
+	 * @since 4.5.0
 	 */
 	static public function prepare( $query, $limit=null, $offset=null ) {
 		return(\OC_DB::prepare($query, $limit, $offset));
@@ -56,6 +68,8 @@ class DB {
 	 *				If this is null or an empty array, all keys of $input will be compared
 	 * @return int number of inserted rows
 	 * @throws \Doctrine\DBAL\DBALException
+	 * @deprecated 8.1.0 use insertIfNotExist() of \OCP\IDBConnection - \OC::$server->getDatabaseConnection()
+	 * @since 5.0.0 - parameter $compare was added in 8.1.0
 	 *
 	 */
 	public static function insertIfNotExist($table, $input, array $compare = null) {
@@ -71,49 +85,61 @@ class DB {
 	 *
 	 * Call this method right after the insert command or other functions may
 	 * cause trouble!
+	 * @deprecated 8.1.0 use lastInsertId() of \OCP\IDBConnection - \OC::$server->getDatabaseConnection()
+	 * @since 4.5.0
 	 */
 	public static function insertid($table=null) {
-		return(\OC_DB::insertid($table));
+		return \OC::$server->getDatabaseConnection()->lastInsertId($table);
 	}
 
 	/**
 	 * Start a transaction
+	 * @deprecated 8.1.0 use beginTransaction() of \OCP\IDBConnection - \OC::$server->getDatabaseConnection()
+	 * @since 4.5.0
 	 */
 	public static function beginTransaction() {
-		\OC_DB::beginTransaction();
+		\OC::$server->getDatabaseConnection()->beginTransaction();
 	}
 
 	/**
 	 * Commit the database changes done during a transaction that is in progress
+	 * @deprecated 8.1.0 use commit() of \OCP\IDBConnection - \OC::$server->getDatabaseConnection()
+	 * @since 4.5.0
 	 */
 	public static function commit() {
-		\OC_DB::commit();
+		\OC::$server->getDatabaseConnection()->commit();
 	}
 
 	/**
 	 * Rollback the database changes done during a transaction that is in progress
+	 * @deprecated 8.1.0 use rollback() of \OCP\IDBConnection - \OC::$server->getDatabaseConnection()
+	 * @since 8.0.0
 	 */
 	public static function rollback() {
-		\OC_DB::rollback();
+		\OC::$server->getDatabaseConnection()->rollback();
 	}
 
 	/**
 	 * Check if a result is an error, works with Doctrine
 	 * @param mixed $result
 	 * @return bool
+	 * @deprecated 8.1.0 Doctrine returns false on error (and throws an exception)
+	 * @since 4.5.0
 	 */
 	public static function isError($result) {
-		return(\OC_DB::isError($result));
+		// Doctrine returns false on error (and throws an exception)
+		return $result === false;
 	}
 
 	/**
 	 * returns the error code and message as a string for logging
 	 * works with DoctrineException
-	 * @param mixed $error
 	 * @return string
+	 * @deprecated 8.1.0 use getError() of \OCP\IDBConnection - \OC::$server->getDatabaseConnection()
+	 * @since 6.0.0
 	 */
-	public static function getErrorMessage($error) {
-		return(\OC_DB::getErrorMessage($error));
+	public static function getErrorMessage() {
+		return \OC::$server->getDatabaseConnection()->getError();
 	}
 
 }
