@@ -8,11 +8,9 @@ OC.L10N.register(
     "Groups" : "Grwpiau",
     "undo" : "dadwneud",
     "never" : "byth",
-    "Encryption" : "Amgryptiad",
     "None" : "Dim",
     "Login" : "Mewngofnodi",
-    "Security Warning" : "Rhybudd Diogelwch",
-    "Please double check the <a href='%s'>installation guides</a>." : "Gwiriwch y <a href='%s'>canllawiau gosod</a> eto.",
+    "Encryption" : "Amgryptiad",
     "by" : "gan",
     "Password" : "Cyfrinair",
     "New password" : "Cyfrinair newydd",
