@@ -1,23 +1,20 @@
 OC.L10N.register(
     "settings",
     {
-    "Security & Setup Warnings" : "Security & Setup Warnings",
-    "Cron" : "Cron",
+    "Security & setup warnings" : "Security & setup warnings",
     "Sharing" : "Sharing",
-    "Security" : "Security",
-    "Email Server" : "Email Server",
+    "Server-side encryption" : "Server-side encryption",
+    "External Storage" : "External Storage",
+    "Cron" : "Cron",
+    "Email server" : "Email server",
     "Log" : "Log",
+    "Server Status" : "Server Status",
+    "Tips & tricks" : "Tips & tricks",
+    "Updates" : "Updates",
     "Authentication error" : "Authentication error",
     "Your full name has been changed." : "Your full name has been changed.",
     "Unable to change full name" : "Unable to change full name",
-    "Files decrypted successfully" : "Files decrypted successfully",
-    "Couldn't decrypt your files, please check your owncloud.log or ask your administrator" : "Couldn't decrypt your files, please check your owncloud.log or ask your administrator",
-    "Couldn't decrypt your files, check your password and try again" : "Couldn't decrypt your files, check your password and try again",
-    "Encryption keys deleted permanently" : "Encryption keys deleted permanently",
-    "Couldn't permanently delete your encryption keys, please check your owncloud.log or ask your administrator" : "Couldn't permanently delete your encryption keys, please check your owncloud.log or ask your administrator",
     "Couldn't remove app." : "Couldn't remove app.",
-    "Backups restored successfully" : "Backups restored successfully",
-    "Couldn't restore your encryption keys, please check your owncloud.log or ask your administrator" : "Couldn't restore your encryption keys, please check your owncloud.log or ask your administrator",
     "Language changed" : "Language changed",
     "Invalid request" : "Invalid request",
     "Admins can't remove themself from the admin group" : "Admins can't remove themselves from the admin group",
@@ -28,22 +25,23 @@ OC.L10N.register(
     "No user supplied" : "No user supplied",
     "Please provide an admin recovery password, otherwise all user data will be lost" : "Please provide an admin recovery password, otherwise all user data will be lost",
     "Wrong admin recovery password. Please check the password and try again." : "Incorrect admin recovery password. Please check the password and try again.",
-    "Back-end doesn't support password change, but the users encryption key was successfully updated." : "Back-end doesn't support password change, but the user's encryption key was successfully updated.",
+    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Backend doesn't support password change, but the user's encryption key was successfully updated.",
     "Unable to change password" : "Unable to change password",
     "Enabled" : "Enabled",
     "Not enabled" : "Not enabled",
-    "Recommended" : "Recommended",
+    "A problem occurred, please check your log files (Error: %s)" : "A problem occurred, please check your log files (Error: %s)",
+    "Migration Completed" : "Migration Completed",
     "Group already exists." : "Group already exists.",
     "Unable to add group." : "Unable to add group.",
     "Unable to delete group." : "Unable to delete group.",
     "log-level out of allowed range" : "log-level out of allowed range",
     "Saved" : "Saved",
     "test email settings" : "test email settings",
-    "If you received this email, the settings seem to be correct." : "If you received this email, the settings seem to be correct.",
-    "A problem occurred while sending the email. Please revise your settings." : "A problem occurred whilst sending the email. Please revise your settings.",
+    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "A problem occurred while sending the email. Please revise your settings. (Error: %s)",
     "Email sent" : "Email sent",
     "You need to set your user email before being able to send test emails." : "You need to set your user email before being able to send test emails.",
     "Invalid mail address" : "Invalid mail address",
+    "A user with that name already exists." : "A user with that name already exists.",
     "Unable to create user." : "Unable to create user.",
     "Your %s account was created" : "Your %s account was created",
     "Unable to delete user." : "Unable to delete user.",
@@ -53,8 +51,16 @@ OC.L10N.register(
     "Email saved" : "Email saved",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "Are you really sure you want add \"{domain}\" as a trusted domain?",
     "Add trusted domain" : "Add trusted domain",
+    "Migration in progress. Please wait until the migration is finished" : "Migration in progress. Please wait until the migration is finished",
+    "Migration started …" : "Migration started …",
     "Sending..." : "Sending...",
+    "Official" : "Official",
+    "Approved" : "Approved",
+    "Experimental" : "Experimental",
     "All" : "All",
+    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use.",
+    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use.",
+    "Update to %s" : "Update to %s",
     "Please wait...." : "Please wait....",
     "Error while disabling app" : "Error whilst disabling app",
     "Disable" : "Disable",
@@ -74,9 +80,7 @@ OC.L10N.register(
     "Strong password" : "Strong password",
     "Valid until {date}" : "Valid until {date}",
     "Delete" : "Delete",
-    "Decrypting files... Please wait, this can take some time." : "Decrypting files... Please wait, this can take some time.",
-    "Delete encryption keys permanently." : "Delete encryption keys permanently.",
-    "Restore encryption keys." : "Restore encryption keys.",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "An error occurred. Please upload an ASCII-encoded PEM certificate.",
     "Groups" : "Groups",
     "Unable to delete {objName}" : "Unable to delete {objName}",
     "Error creating group" : "Error creating group",
@@ -93,9 +97,9 @@ OC.L10N.register(
     "A valid password must be provided" : "A valid password must be provided",
     "A valid email must be provided" : "A valid email must be provided",
     "__language_name__" : "English (British English)",
-    "Personal Info" : "Personal Info",
+    "Sync clients" : "Sync clients",
+    "Personal info" : "Personal info",
     "SSL root certificates" : "SSL root certificates",
-    "Encryption" : "Encryption",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Everything (fatal issues, errors, warnings, info, debug)",
     "Info, warnings, errors and fatal issues" : "Info, warnings, errors and fatal issues",
     "Warnings, errors and fatal issues" : "Warnings, errors and fatal issues",
@@ -107,35 +111,20 @@ OC.L10N.register(
     "NT LAN Manager" : "NT LAN Manager",
     "SSL" : "SSL",
     "TLS" : "TLS",
-    "Security Warning" : "Security Warning",
-    "You are accessing %s via HTTP. We strongly suggest you configure your server to require using HTTPS instead." : "You are accessing %s via HTTP. We strongly suggest you configure your server to require using HTTPS instead.",
-    "Read-Only config enabled" : "Read-Only config enabled",
+    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response.",
+    "Please check the installation documentation for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Please check the installation documentation for php configuration notes and the php configuration of your server, especially when using php-fpm.",
     "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update.",
-    "Setup Warning" : "Setup Warning",
     "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator.",
-    "Database Performance Info" : "Database Performance Info",
-    "Microsoft Windows Platform" : "Microsoft Windows Platform",
     "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience.",
-    "Module 'fileinfo' missing" : "Module 'fileinfo' missing",
     "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "The PHP module 'fileinfo' is missing. We strongly recommend enabling this module to get best results with mime-type detection.",
-    "PHP charset is not set to UTF-8" : "PHP charset is not set to UTF-8",
-    "PHP charset is not set to UTF-8. This can cause major issues with non-ASCII characters in file names. We highly recommend to change the value of 'default_charset' php.ini to 'UTF-8'." : "PHP charset is not set to UTF-8. This can cause major issues with non-ASCII characters in file names. We highly recommend to change the value of 'default_charset' php.ini to 'UTF-8'.",
-    "Locale not working" : "Locale not working",
     "System locale can not be set to a one which supports UTF-8." : "System locale can not be set to a one which supports UTF-8.",
     "This means that there might be problems with certain characters in file names." : "This means that there might be problems with certain characters in file names.",
     "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "We strongly suggest installing the required packages on your system to support one of the following locales: %s.",
-    "URL generation in notification emails" : "URL generation in notification emails",
     "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")",
-    "Configuration Checks" : "Configuration Checks",
-    "No problems found" : "No problems found",
-    "Please double check the <a href='%s'>installation guides</a>." : "Please double check the <a href='%s'>installation guides</a>.",
-    "Last cron was executed at %s." : "Last cron was executed at %s.",
-    "Last cron was executed at %s. This is more than an hour ago, something seems wrong." : "Last cron was executed at %s. This is more than an hour ago, something seems wrong.",
-    "Cron was not executed yet!" : "Cron was not executed yet!",
-    "Execute one task with each page loaded" : "Execute one task with each page loaded",
-    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php is registered at a webcron service to call cron.php every 15 minutes over http.",
-    "Use system's cron service to call the cron.php file every 15 minutes." : "Use system's cron service to call the cron.php file every 15 minutes.",
+    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:",
+    "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>.",
+    "Open documentation" : "Open documentation",
     "Allow apps to use the Share API" : "Allow apps to use the Share API",
     "Allow users to share via link" : "Allow users to share via link",
     "Enforce password protection" : "Enforce password protection",
@@ -150,13 +139,23 @@ OC.L10N.register(
     "Allow users to send mail notification for shared files to other users" : "Allow users to send email notification for shared files to other users",
     "Exclude groups from sharing" : "Exclude groups from sharing",
     "These groups will still be able to receive shares, but not to initiate them." : "These groups will still be able to receive shares, but not to initiate them.",
-    "Enforce HTTPS" : "Enforce HTTPS",
-    "Forces the clients to connect to %s via an encrypted connection." : "Forces the clients to connect to %s via an encrypted connection.",
-    "Enforce HTTPS for subdomains" : "Enforce HTTPS for subdomains",
-    "Forces the clients to connect to %s and subdomains via an encrypted connection." : "Forces the clients to connect to %s and subdomains via an encrypted connection.",
-    "Please connect to your %s via HTTPS to enable or disable the SSL enforcement." : "Please connect to your %s via HTTPS to enable or disable the SSL enforcement.",
+    "Last cron job execution: %s." : "Last cron job execution: %s.",
+    "Last cron job execution: %s. Something seems wrong." : "Last cron job execution: %s. Something seems wrong.",
+    "Cron was not executed yet!" : "Cron was not executed yet!",
+    "Execute one task with each page loaded" : "Execute one task with each page loaded",
+    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php is registered at a webcron service to call cron.php every 15 minutes over http.",
+    "Use system's cron service to call the cron.php file every 15 minutes." : "Use system's cron service to call the cron.php file every 15 minutes.",
+    "Enable server-side encryption" : "Enable server-side encryption",
+    "Encryption is a one way process. Once encryption is enabled, all files from that point forward will be encrypted on the server and it will not be possible to disable encryption at a later date. This is the final warning: Do you really want to enable encryption?" : "Encryption is a one way process. Once encryption is enabled, all files from that point forward will be encrypted on the server and it will not be possible to disable encryption at a later date. This is the final warning: Do you really want to enable encryption?",
+    "Enable encryption" : "Enable encryption",
+    "No encryption module loaded, please enable an encryption module in the app menu." : "No encryption module loaded, please enable an encryption module in the app menu.",
+    "Select default encryption module:" : "Select default encryption module:",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one.",
+    "Start migration" : "Start migration",
     "This is used for sending out notifications." : "This is used for sending out notifications.",
     "Send mode" : "Send mode",
+    "Encryption" : "Encryption",
     "From address" : "From address",
     "mail" : "mail",
     "Authentication method" : "Authentication method",
@@ -173,47 +172,60 @@ OC.L10N.register(
     "Download logfile" : "Download logfile",
     "More" : "More",
     "Less" : "Less",
-    "The logfile is bigger than 100MB. Downloading it may take some time!" : "The logfile is bigger than 100MB. Downloading it may take some time!",
+    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "The logfile is larger than 100 MB. Downloading it may take some time!",
+    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite is used as database. For larger installations, we recommend you switch to a different database backend.",
+    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Especially when using the desktop client for file syncing, the use of SQLite is discouraged.",
+    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>.",
+    "How to do backups" : "How to do backups",
+    "Advanced monitoring" : "Advanced monitoring",
+    "Performance tuning" : "Performance tuning",
+    "Improving the config.php" : "Improving the config.php",
+    "Theming" : "Theming",
+    "Hardening and security guidance" : "Hardening and security guidance",
     "Version" : "Version",
-    "Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." : "Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public Licence\">AGPL</abbr></a>.",
-    "More apps" : "More apps",
-    "Add your app" : "Add your app",
+    "Developer documentation" : "Developer documentation",
+    "Experimental applications ahead" : "Experimental applications ahead",
+    "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches.",
     "by" : "by",
     "licensed" : "licensed",
     "Documentation:" : "Documentation:",
     "User Documentation" : "User Documentation",
     "Admin Documentation" : "Admin Documentation",
+    "Show description …" : "Show description …",
+    "Hide description …" : "Hide description …",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "This app cannot be installed because the following dependencies are not fulfilled:",
-    "Update to %s" : "Update to %s",
     "Enable only for specific groups" : "Enable only for specific groups",
     "Uninstall App" : "Uninstall App",
+    "Enable experimental apps" : "Enable experimental apps",
+    "No apps found for your version" : "No apps found for your version",
     "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>",
     "Cheers!" : "Cheers!",
     "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n",
-    "Administrator Documentation" : "Administrator Documentation",
-    "Online Documentation" : "Online Documentation",
+    "User documentation" : "User documentation",
+    "Administrator documentation" : "Administrator documentation",
+    "Online documentation" : "Online documentation",
     "Forum" : "Forum",
-    "Bugtracker" : "Bugtracker",
-    "Commercial Support" : "Commercial Support",
+    "Issue tracker" : "Issue tracker",
+    "Commercial support" : "Commercial support",
     "Get the apps to sync your files" : "Get the apps to sync your files",
     "Desktop client" : "Desktop client",
     "Android app" : "Android app",
     "iOS app" : "iOS app",
-    "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\">spread the word</a>!" : "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\">spread the word</a>!",
+    "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!",
     "Show First Run Wizard again" : "Show First Run Wizard again",
     "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "You have used <strong>%s</strong> of the available <strong>%s</strong>",
     "Password" : "Password",
-    "Your password was changed" : "Your password was changed",
     "Unable to change your password" : "Unable to change your password",
     "Current password" : "Current password",
     "New password" : "New password",
     "Change password" : "Change password",
-    "Full Name" : "Full Name",
+    "Full name" : "Full name",
     "No display name set" : "No display name set",
     "Email" : "Email",
     "Your email address" : "Your email address",
     "Fill in an email address to enable password recovery and receive notifications" : "Fill in an email address to enable password recovery and receive notifications",
     "No email address set" : "No email address set",
+    "You are member of the following groups:" : "You are member of the following groups:",
     "Profile picture" : "Profile picture",
     "Upload new" : "Upload new",
     "Select new from Files" : "Select new from Files",
@@ -228,13 +240,8 @@ OC.L10N.register(
     "Valid until" : "Valid until",
     "Issued By" : "Issued By",
     "Valid until %s" : "Valid until %s",
-    "Import Root Certificate" : "Import Root Certificate",
-    "The encryption app is no longer enabled, please decrypt all your files" : "The encryption app is no longer enabled, please decrypt all your files",
-    "Log-in password" : "Log-in password",
-    "Decrypt all Files" : "Decrypt all Files",
-    "Your encryption keys are moved to a backup location. If something went wrong you can restore the keys. Only delete them permanently if you are sure that all files are decrypted correctly." : "Your encryption keys are moved to a backup location. If something went wrong you can restore the keys. Only delete them permanently if you are sure that all files are decrypted correctly.",
-    "Restore Encryption Keys" : "Restore Encryption Keys",
-    "Delete Encryption Keys" : "Delete Encryption Keys",
+    "Import root certificate" : "Import root certificate",
+    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public Licence\">AGPL</abbr>{linkclose}.",
     "Show storage location" : "Show storage location",
     "Show last log in" : "Show last log in",
     "Show user backend" : "Show user backend",
@@ -254,6 +261,7 @@ OC.L10N.register(
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Please enter storage quota (e.g. \"512 MB\" or \"12 GB\")",
     "Unlimited" : "Unlimited",
     "Other" : "Other",
+    "Full Name" : "Full Name",
     "Group Admin for" : "Group Admin for",
     "Quota" : "Quota",
     "Storage Location" : "Storage Location",
