@@ -1,23 +1,22 @@
 OC.L10N.register(
     "settings",
     {
-    "Security & Setup Warnings" : "Alertes de sécurité ou de configuration",
-    "Cron" : "Cron",
+    "APCu" : "APCu",
+    "Redis" : "Redis",
+    "Security & setup warnings" : "Avertissements de sécurité & configuration",
     "Sharing" : "Partage",
-    "Security" : "Sécurité",
-    "Email Server" : "Serveur mail",
+    "Server-side encryption" : "Chiffrement côté serveur",
+    "External Storage" : "Stockage externe",
+    "Cron" : "Cron",
+    "Email server" : "Serveur mail",
     "Log" : "Log",
+    "Server Status" : "Statut du serveur",
+    "Tips & tricks" : "Trucs et astuces",
+    "Updates" : "Mises à jour",
     "Authentication error" : "Erreur d'authentification",
     "Your full name has been changed." : "Votre nom complet a été modifié.",
     "Unable to change full name" : "Impossible de changer le nom complet",
-    "Files decrypted successfully" : "Fichiers déchiffrés avec succès",
-    "Couldn't decrypt your files, please check your owncloud.log or ask your administrator" : "Impossible de déchiffrer vos fichiers. Veuillez vérifier votre owncloud.log ou demander à votre administrateur",
-    "Couldn't decrypt your files, check your password and try again" : "Impossible de déchiffrer vos fichiers. Vérifiez votre mot de passe et essayez à nouveau",
-    "Encryption keys deleted permanently" : "Clés de chiffrement définitivement supprimées.",
-    "Couldn't permanently delete your encryption keys, please check your owncloud.log or ask your administrator" : "Impossible de supprimer définitivement vos clés de chiffrement. Merci de consulter le fichier owncloud.log ou de demander à votre administrateur",
     "Couldn't remove app." : "Impossible de supprimer l'application.",
-    "Backups restored successfully" : "Sauvegardes restaurées avec succès",
-    "Couldn't restore your encryption keys, please check your owncloud.log or ask your administrator" : "Impossible de restaurer vos clés de chiffrement. Merci de consulter le fichier owncloud.log ou de demander à votre administrateur",
     "Language changed" : "Langue changée",
     "Invalid request" : "Requête non valide",
     "Admins can't remove themself from the admin group" : "Les administrateurs ne peuvent pas se retirer eux-mêmes du groupe admin",
@@ -28,33 +27,43 @@ OC.L10N.register(
     "No user supplied" : "Aucun utilisateur fourni",
     "Please provide an admin recovery password, otherwise all user data will be lost" : "Veuillez fournir un mot de passe administrateur de récupération de données, sinon toutes les données de l'utilisateur seront perdues",
     "Wrong admin recovery password. Please check the password and try again." : "Mot de passe administrateur de récupération de données non valable. Veuillez vérifier le mot de passe et essayer à nouveau.",
-    "Back-end doesn't support password change, but the users encryption key was successfully updated." : "L'infrastructure d'arrière-plan ne permet pas la modification de mot de passe, mais la clef de chiffrement des utilisateurs a été mise à jour avec succès.",
+    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "L'infrastructure d'arrière-plan ne supporte pas la modification de mot de passe, mais la clef de chiffrement de l'utilisateur a été mise à jour avec succès.",
     "Unable to change password" : "Impossible de modifier le mot de passe",
     "Enabled" : "Activées",
     "Not enabled" : "Désactivées",
-    "Recommended" : "Recommandées",
+    "A problem occurred, please check your log files (Error: %s)" : "Une erreur est survenue, veuillez vérifier vos fichiers de log (Erreur: %s)",
+    "Migration Completed" : "Migration terminée",
     "Group already exists." : "Ce groupe existe déjà.",
     "Unable to add group." : "Impossible d'ajouter le groupe.",
     "Unable to delete group." : "Impossible de supprimer le groupe.",
     "log-level out of allowed range" : "niveau de journalisation hors borne",
     "Saved" : "Sauvegardé",
     "test email settings" : "tester les paramètres d'e-mail",
-    "If you received this email, the settings seem to be correct." : "Si vous recevez cet email, c'est que les paramètres sont corrects",
-    "A problem occurred while sending the email. Please revise your settings." : "Une erreur est survenue lors de l'envoi de l'e-mail. Veuillez vérifier vos paramètres.",
+    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Une erreur est survenue lors de l'envoi de l'e-mail. Veuillez vérifier vos paramètres. (Erreur: %s)",
     "Email sent" : "Email envoyé",
-    "You need to set your user email before being able to send test emails." : "Vous devez configurer votre e-mail d'utilisateur avant de pouvoir envoyer des e-mails de test.",
+    "You need to set your user email before being able to send test emails." : "Vous devez définir une adresse email dans vos paramètres personnels avant de pouvoir envoyer des courriels de test.",
     "Invalid mail address" : "Adresse email non valide",
+    "A user with that name already exists." : "Un utilisateur à ce nom existe déjà.",
     "Unable to create user." : "Impossible de créer l'utilisateur.",
     "Your %s account was created" : "Votre compte %s a été créé.",
     "Unable to delete user." : "Impossible de supprimer l'utilisateur.",
     "Forbidden" : "Iinterdit",
-    "Invalid user" : "Utilisateur non valide",
+    "Invalid user" : "Utilisateur non valable",
     "Unable to change mail address" : "Impossible de modifier l'adresse de courriel",
-    "Email saved" : "E-mail sauvegardé",
+    "Email saved" : "Email sauvegardé",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "Êtes-vous vraiment sûr de vouloir ajouter \"{domain}\" comme domaine de confiance ?",
     "Add trusted domain" : "Ajouter un domaine de confiance",
+    "Migration in progress. Please wait until the migration is finished" : "Migration en cours. Veuillez attendre que celle-ci se termine",
+    "Migration started …" : "Migration démarrée...",
     "Sending..." : "Envoi en cours...",
+    "Official" : "Officielle",
+    "Approved" : "Approuvée",
+    "Experimental" : "Expérimentale",
     "All" : "Tous",
+    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Les applications officielles sont développées par et avec la communauté ownCloud. Elles permettent à ownCloud d'offrir ses fonctionnalités principales et sont prêtes pour une utilisation en environnement de production. ",
+    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Les applications approuvées sont créées par des développeurs de confiance et ont passé les test de sécurité. Elles sont activement maintenues dans un dépôt ouvert et leurs développeurs les considèrent stables pour une utilisation normale.",
+    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Cette application est nouvelle ou instable, et sa sécurité n'a pas été vérifiée. Installez-la à vos risques et périls!",
+    "Update to %s" : "Mettre à niveau vers la version %s",
     "Please wait...." : "Veuillez patienter…",
     "Error while disabling app" : "Erreur lors de la désactivation de l'application",
     "Disable" : "Désactiver",
@@ -62,8 +71,8 @@ OC.L10N.register(
     "Error while enabling app" : "Erreur lors de l'activation de l'application",
     "Updating...." : "Mise à jour...",
     "Error while updating app" : "Erreur lors de la mise à jour de l'application",
-    "Updated" : "Mise à jour effectuée avec succès",
-    "Uninstalling ...." : "Désintallation...",
+    "Updated" : "Mise à jour effectuée",
+    "Uninstalling ...." : "Désinstallation...",
     "Error while uninstalling app" : "Erreur lors de la désinstallation de l'application",
     "Uninstall" : "Désinstaller",
     "Select a profile picture" : "Selectionner une photo de profil ",
@@ -74,9 +83,7 @@ OC.L10N.register(
     "Strong password" : "Mot de passe de forte sécurité",
     "Valid until {date}" : "Valide jusqu'au {date}",
     "Delete" : "Supprimer",
-    "Decrypting files... Please wait, this can take some time." : "Déchiffrement en cours... Cela peut prendre un certain temps.",
-    "Delete encryption keys permanently." : "Supprimer définitivement les clés de chiffrement",
-    "Restore encryption keys." : "Restaurer les clés de chiffrement",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Une erreur est survenue. Veuillez fournir un certificat PEM encodé au format ASCII.",
     "Groups" : "Groupes",
     "Unable to delete {objName}" : "Impossible de supprimer {objName}",
     "Error creating group" : "Erreur lors de la création du groupe",
@@ -93,58 +100,41 @@ OC.L10N.register(
     "A valid password must be provided" : "Un mot de passe valide doit être saisi",
     "A valid email must be provided" : "Vous devez fournir une adresse de courriel valide",
     "__language_name__" : "Français",
-    "Personal Info" : "Informations personnelles",
+    "Sync clients" : "Clients de synchronisation",
+    "Personal info" : "Informations personnelles",
     "SSL root certificates" : "Certificats racine SSL",
-    "Encryption" : "Chiffrement",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Tout (erreurs fatales, erreurs, avertissements, informations, debogage)",
     "Info, warnings, errors and fatal issues" : "Informations, avertissements, erreurs et erreurs fatales",
     "Warnings, errors and fatal issues" : "Avertissements, erreurs et erreurs fatales",
     "Errors and fatal issues" : "Erreurs et erreurs fatales",
     "Fatal issues only" : "Erreurs fatales uniquement",
     "None" : "Aucun",
-    "Login" : "Connexion",
+    "Login" : "Login",
     "Plain" : "En clair",
     "NT LAN Manager" : "Gestionnaire du réseau NT",
     "SSL" : "SSL",
     "TLS" : "TLS",
-    "Security Warning" : "Avertissement de sécurité",
-    "You are accessing %s via HTTP. We strongly suggest you configure your server to require using HTTPS instead." : "Vous accédez à %s via HTTP. Nous vous recommandons fortement de configurer votre serveur pour forcer l'utilisation de HTTPS à la place.",
-    "Read-Only config enabled" : "Configuration en mode lecture seule activée",
+    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "php ne semble pas être configuré de manière à récupérer les valeurs des variables d’environnement. Le test de la commande getenv(\"PATH\") retourne seulement une réponse vide. ",
+    "Please check the installation documentation for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Veuillez verifier la documentation d'installation concernant les instructions de configuration de php ainsi que la configuration de votre serveur, en particulier dans le cas où vous utilisez php-fpm.",
     "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "La configuration est en mode lecture seule. Ceci empêche la modification de certaines configurations via l'interface web. De plus, le fichier doit être passé manuellement en lecture-écriture pour chaque mise à jour.",
-    "Setup Warning" : "Avertissement, problème de configuration",
     "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP est apparemment configuré pour supprimer les blocs de documentation internes. Cela rendra plusieurs applications de base inaccessibles.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "La raison est probablement l'utilisation d'un cache / accélérateur tel que Zend OPcache ou eAccelerator.",
-    "Database Performance Info" : "Performances de la base de données",
-    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite est actuellement utilisé comme gestionnaire de base de données. Pour des installations plus volumineuses, nous vous conseillons d'utiliser un autre gestionnaire de base de données.",
-    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "En particulier si vous utilisez le client de bureau pour synchroniser vos données : l'utilisation de SQLite est alors déconseillée.",
-    "To migrate to another database use the command line tool: 'occ db:convert-type'" : "Pour migrer vers un autre type de base de données, utilisez la ligne de commande : 'occ db:convert-type'",
-    "Microsoft Windows Platform" : "Plateforme Microsoft Windows",
     "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Votre serveur fonctionne actuellement sur une plateforme Microsoft Windows. Nous vous recommandons fortement d'utiliser une plateforme Linux pour une expérience utilisateur optimale.",
-    "Module 'fileinfo' missing" : "Module 'fileinfo' manquant",
-    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Le module PHP 'fileinfo' est manquant. Il est vivement recommandé de l'activer afin d'obtenir de meilleurs résultats pour la détection des types de fichiers.",
-    "PHP charset is not set to UTF-8" : "Le jeu de caractères PHP n'est pas réglé sur UTF-8",
-    "PHP charset is not set to UTF-8. This can cause major issues with non-ASCII characters in file names. We highly recommend to change the value of 'default_charset' php.ini to 'UTF-8'." : "Le jeu de caractères PHP n'est pas réglé sur UTF-8. Ceci peut entraîner des problèmes majeurs avec les noms de fichiers contenant des caractères non-ASCII. Nous recommandons fortement de changer la valeur de 'default_charset' dans php.ini par 'UTF-8'.",
-    "Locale not working" : "Localisation non fonctionnelle",
+    "%1$s below version %2$s is installed, for stability and performance reasons we recommend to update to a newer %1$s version." : "Une version de %1$s plus ancienne que %2$s est installée. Pour améliorer la stabilité et les performances, nous recommandons de mettre %1$s à jour.",
+    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Le module PHP 'fileinfo' est manquant. Il est vivement recommandé de l'activer afin d'obtenir de meilleurs résultats de détection mime-type.",
     "System locale can not be set to a one which supports UTF-8." : "Les paramètres régionaux ne peuvent pas être configurés avec prise en charge d'UTF-8.",
     "This means that there might be problems with certain characters in file names." : "Cela signifie qu'il pourrait y avoir des problèmes avec certains caractères dans les noms de fichier.",
-    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Nous vous recommandons d'installer sur votre système les paquets requis à la prise en charge de l'un des paramètres régionaux suivants : %s",
-    "URL generation in notification emails" : "Génération d'URL dans les mails de notification",
+    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Nous vous recommandons d'installer sur votre système les paquets nécessaires à la prise en charge de l'un des paramètres régionaux suivants : %s",
     "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Si votre installation n'a pas été effectuée à la racine du domaine et qu'elle utilise le cron du système, il peut y avoir des problèmes avec la génération d'URL. Pour les éviter, veuillez configurer l'option \"overwrite.cli.url\" de votre fichier config.php avec le chemin de la racine de votre installation (suggéré : \"%s\")",
-    "Configuration Checks" : "Vérification de la configuration",
-    "No problems found" : "Aucun problème trouvé",
-    "Please double check the <a href='%s'>installation guides</a>." : "Veuillez vous référer au <a href='%s'>guide d'installation</a>.",
-    "Last cron was executed at %s." : "Le dernier cron s'est exécuté à la date suivante : %s.",
-    "Last cron was executed at %s. This is more than an hour ago, something seems wrong." : "Le dernier cron s'est exécuté à la date suivante : %s. Cela fait plus d'une heure, quelque chose a du mal se passer.",
-    "Cron was not executed yet!" : "Le cron n'a pas encore été exécuté !",
-    "Execute one task with each page loaded" : "Exécute une tâche à chaque chargement de page",
-    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php est enregistré en tant que service webcron pour appeler cron.php toutes les 15 minutes via http.",
-    "Use system's cron service to call the cron.php file every 15 minutes." : "Utilisez le service cron du système pour appeler le fichier cron.php toutes les 15 minutes.",
+    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "La tâche cron n'a pu s'exécuter via CLI. Ces erreurs techniques sont apparues :",
+    "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Consultez les <a target=\"_blank\" href=\"%s\">guides d'installation ↗</a>,  et cherchez des erreurs ou avertissements dans  <a href=\"#log-section\">les logs</a>.",
+    "Open documentation" : "Voir la documentation",
     "Allow apps to use the Share API" : "Autoriser les applications à utiliser l'API de partage",
     "Allow users to share via link" : "Autoriser les utilisateurs à partager par lien",
     "Enforce password protection" : "Obliger la protection par mot de passe",
     "Allow public uploads" : "Autoriser les téléversements publics",
     "Allow users to send mail notification for shared files" : "Autoriser les utilisateurs à envoyer des notifications par courriel concernant les partages",
-    "Set default expiration date" : "Spécifier la date d'expiration par défaut",
+    "Set default expiration date" : "Spécifier une date d'expiration par défaut",
     "Expire after " : "Expiration après ",
     "days" : "jours",
     "Enforce expiration date" : "Imposer la date d'expiration",
@@ -153,15 +143,25 @@ OC.L10N.register(
     "Allow users to send mail notification for shared files to other users" : "Autoriser les utilisateurs à envoyer une notification par courriel concernant les fichiers partagés",
     "Exclude groups from sharing" : "Empêcher certains groupes de partager",
     "These groups will still be able to receive shares, but not to initiate them." : "Ces groupes ne pourront plus initier de partage, mais ils pourront toujours rejoindre les partages faits par d'autres. ",
-    "Enforce HTTPS" : "Forcer HTTPS",
-    "Forces the clients to connect to %s via an encrypted connection." : "Forcer les clients à se connecter à %s via une connexion chiffrée.",
-    "Enforce HTTPS for subdomains" : "Forcer HTTPS pour les sous domaines",
-    "Forces the clients to connect to %s and subdomains via an encrypted connection." : "Force les clients à se connecter à %s et aux sous domaines via une connexion chiffrée.",
-    "Please connect to your %s via HTTPS to enable or disable the SSL enforcement." : "Veuillez vous connecter à cette instance %s via HTTPS pour activer ou désactiver SSL.",
+    "Last cron job execution: %s." : "Dernière tâche cron exécutée : %s.",
+    "Last cron job execution: %s. Something seems wrong." : "Dernière tâche cron exécutée : %s. Quelque chose s'est mal passé.",
+    "Cron was not executed yet!" : "Le cron n'a pas encore été exécuté !",
+    "Execute one task with each page loaded" : "Exécute une tâche à chaque chargement de page",
+    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "Utilisez un service webcron pour exécuter cron.php toutes les 15 minutes par HTTP",
+    "Use system's cron service to call the cron.php file every 15 minutes." : "Utilisez le service cron du système pour appeler le fichier cron.php toutes les 15 minutes.",
+    "Enable server-side encryption" : "Activer le chiffrement côté serveur",
+    "Encryption is a one way process. Once encryption is enabled, all files from that point forward will be encrypted on the server and it will not be possible to disable encryption at a later date. This is the final warning: Do you really want to enable encryption?" : "Le chiffrement est un processus à sens unique. Une fois que le chiffrement est activé, tous les fichiers à partir de ce moment seront chiffrés sur le serveur et il ne sera pas possible de désactiver le chiffrement ultérieurement. Ceci est le dernier avertissement : Voulez-vous vraiment activer le chiffrement?",
+    "Enable encryption" : "Activer le chiffrement",
+    "No encryption module loaded, please enable an encryption module in the app menu." : "Aucun module de chiffrement n'est chargé. Merci d'activer un module de chiffrement dans le menu des applications.",
+    "Select default encryption module:" : "Sélectionnez le module de chiffrement par défaut :",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Vous devez migrer vos clés de chiffrement de l'ancienne version (ownCloud <= 8.0) vers la nouvelle. Veuillez activer l'application \"Default Encryption Module\" et exécuter 'occ encryption:migrate'",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Vous devez migrer vos clés de chiffrement de l'ancienne version (ownCloud <= 8.0) vers la nouvelle.",
+    "Start migration" : "Démarrer la migration",
     "This is used for sending out notifications." : "Ceci est utilisé pour l'envoi des notifications.",
     "Send mode" : "Mode d'envoi",
+    "Encryption" : "Chiffrement",
     "From address" : "Adresse source",
-    "mail" : "courriel",
+    "mail" : "mail",
     "Authentication method" : "Méthode d'authentification",
     "Authentication required" : "Authentification requise",
     "Server address" : "Adresse du serveur",
@@ -171,52 +171,65 @@ OC.L10N.register(
     "SMTP Password" : "Mot de passe SMTP",
     "Store credentials" : "Enregistrer les identifiants",
     "Test email settings" : "Tester les paramètres e-mail",
-    "Send email" : "Envoyer un e-mail",
+    "Send email" : "Envoyer un mail",
     "Log level" : "Niveau de log",
     "Download logfile" : "Télécharger le fichier de journalisation",
     "More" : "Plus",
     "Less" : "Moins",
-    "The logfile is bigger than 100MB. Downloading it may take some time!" : "Le fichier de journalisation dépasse les 100Mo. Son téléchargement pourra prendre du temps !",
+    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "La taille du fichier journal excède 100 Mo. Le télécharger peut prendre un certain temps!",
+    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite est actuellement utilisé comme gestionnaire de base de données. Pour des installations plus volumineuses, nous vous conseillons d'utiliser un autre gestionnaire de base de données.",
+    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "L'utilisation de SQLite est particulièrement déconseillée si vous utilisez le client de bureau pour synchroniser vos données.",
+    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "Pour migrer vers un autre type de base de données, utilisez la ligne de commande : 'occ db:convert-type' ou consultez la <a target=\"_blank\" href=\"%s\">documentation ↗</a>.",
+    "How to do backups" : "Comment faire des sauvegardes",
+    "Advanced monitoring" : "Surveillance avancée",
+    "Performance tuning" : "Ajustement des performances",
+    "Improving the config.php" : "Amélioration du config.php ",
+    "Theming" : "Personnalisation de l'apparence",
+    "Hardening and security guidance" : "Guide pour le renforcement et la sécurité",
     "Version" : "Version",
-    "Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." : "Développé par la <a href=\"http://ownCloud.org/contact\" target=\"_blank\">communauté ownCloud</a>, le <a href=\"https://github.com/owncloud\" target=\"_blank\">code source</a> est publié sous license <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>.",
-    "More apps" : "Plus d'applications",
-    "Add your app" : "Ajouter votre application",
+    "Developer documentation" : "Documentation pour développeurs",
+    "Experimental applications ahead" : "Attention! Applications expérimentales",
+    "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "Les applications expérimentales n'ont pas été testées pour les problèmes de sécurité, sont nouvelles ou connues comme étant instables et sont encore en développement. Les installer peut causer des pertes de données ou des failles de sécurités. ",
     "by" : "par",
     "licensed" : "Sous licence",
     "Documentation:" : "Documentation :",
     "User Documentation" : "Documentation utilisateur",
     "Admin Documentation" : "Documentation administrateur",
+    "Show description …" : "Afficher la description...",
+    "Hide description …" : "Masquer la description...",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Cette application ne peut être installée à cause de ces dépendances non satisfaites :",
-    "Update to %s" : "Mettre à niveau vers la version %s",
     "Enable only for specific groups" : "Activer uniquement pour certains groupes",
     "Uninstall App" : "Désinstaller l'application",
+    "Enable experimental apps" : "Activer les applications expérimentales",
+    "No apps found for your version" : "Pas d'application trouvée pour votre version",
     "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Bonjour,<br><br>Un compte %s a été créé pour vous.<br><br>Votre nom d'utilisateur est : %s<br>Visitez votre compte : <a href=\"%s\">%s</a><br><br>",
     "Cheers!" : "À bientôt !",
     "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Bonjour,<br><br>Un compte %s a été créé pour vous.<br><br>Votre nom d'utilisateur est : %s<br>Visitez votre compte : %s<br><br>\n",
-    "Administrator Documentation" : "Documentation administrateur",
-    "Online Documentation" : "Documentation en ligne",
+    "User documentation" : "Documentation utilisateur",
+    "Administrator documentation" : "Documentation administrateur",
+    "Online documentation" : "Documentation en ligne",
     "Forum" : "Forum",
-    "Bugtracker" : "Suivi de bugs",
-    "Commercial Support" : "Support commercial",
+    "Issue tracker" : "Suivi de problèmes",
+    "Commercial support" : "Support commercial",
     "Get the apps to sync your files" : "Obtenez les applications de synchronisation de vos fichiers",
     "Desktop client" : "Client de bureau",
     "Android app" : "Application Android",
     "iOS app" : "Application iOS",
-    "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\">spread the word</a>!" : "Si voulez soutenir le projet, \n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\">rejoignez le développement</a>\n\t\tou \n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\">parlez-en</a> !",
+    "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Si vous souhaitez apporter votre support au projet\n        <a href=\"https://owncloud.org/contribute\"\n            target=\"_blank\" rel=\"noreferrer\">rejoignez le développement</a>\n        ou\n        <a href=\"https://owncloud.org/promote\"\n            target=\"_blank\" rel=\"noreferrer\">faites passer le mot</a> !",
     "Show First Run Wizard again" : "Revoir la fenêtre d'accueil affichée lors de votre première connexion",
     "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "Vous utilisez <strong>%s</strong> des <strong>%s<strong> disponibles",
     "Password" : "Mot de passe",
-    "Your password was changed" : "Votre mot de passe a été changé",
     "Unable to change your password" : "Impossible de changer votre mot de passe",
     "Current password" : "Mot de passe actuel",
     "New password" : "Nouveau mot de passe",
     "Change password" : "Changer de mot de passe",
-    "Full Name" : "Nom complet",
+    "Full name" : "Nom complet",
     "No display name set" : "Aucun nom d'affichage configuré",
     "Email" : "Adresse mail",
-    "Your email address" : "Votre adresse e-mail",
+    "Your email address" : "Votre adresse mail",
     "Fill in an email address to enable password recovery and receive notifications" : "Saisissez votre adresse mail pour permettre la réinitialisation du mot de passe et la réception des notifications",
     "No email address set" : "Aucune adresse e-mail configurée",
+    "You are member of the following groups:" : "Vous êtes membre des groupes suivants :",
     "Profile picture" : "Photo de profil",
     "Upload new" : "Nouvelle depuis votre ordinateur",
     "Select new from Files" : "Nouvelle depuis les Fichiers",
@@ -231,17 +244,12 @@ OC.L10N.register(
     "Valid until" : "Valide jusqu'à",
     "Issued By" : "Délivré par",
     "Valid until %s" : "Valide jusqu'à %s",
-    "Import Root Certificate" : "Importer un certificat racine",
-    "The encryption app is no longer enabled, please decrypt all your files" : "L'app de chiffrement n’est plus activée, veuillez déchiffrer tous vos fichiers",
-    "Log-in password" : "Mot de passe de connexion",
-    "Decrypt all Files" : "Déchiffrer tous les fichiers",
-    "Your encryption keys are moved to a backup location. If something went wrong you can restore the keys. Only delete them permanently if you are sure that all files are decrypted correctly." : "Vos clés de chiffrement ont été déplacées dans l'emplacement de backup. Si quelque chose devait mal se passer, vous pouvez restaurer les clés. Choisissez la suppression permanente seulement si vous êtes sûr que tous les fichiers ont été déchiffrés correctement.",
-    "Restore Encryption Keys" : "Restaurer les clés de chiffrement",
-    "Delete Encryption Keys" : "Supprimer les clés de chiffrement",
+    "Import root certificate" : "Importer un certificat racine",
+    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Développé par la {communityopen}communauté ownCloud{linkclose}, le {githubopen}code source{linkclose} est sous licence {licenseopen}<abbr lang=\"en\" title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
     "Show storage location" : "Afficher l'emplacement du stockage",
     "Show last log in" : "Montrer la dernière connexion",
     "Show user backend" : "Montrer la source de l'identifiant",
-    "Send email to new user" : "Envoyer un courriel au nouvel utilisateur",
+    "Send email to new user" : "Envoyer un courriel aux utilisateurs créés",
     "Show email address" : "Afficher l'adresse email",
     "Username" : "Nom d'utilisateur",
     "E-Mail" : "Courriel",
@@ -257,6 +265,7 @@ OC.L10N.register(
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Veuillez entrer le quota de stockage (ex. \"512 MB\" ou \"12 GB\")",
     "Unlimited" : "Illimité",
     "Other" : "Autre",
+    "Full Name" : "Nom complet",
     "Group Admin for" : "Administrateur de groupe pour",
     "Quota" : "Quota",
     "Storage Location" : "Emplacement du Stockage",
