@@ -1,23 +1,22 @@
 OC.L10N.register(
     "settings",
     {
-    "Security & Setup Warnings" : "Предупреждения безопасности и настроек",
-    "Cron" : "Cron (планировщик задач)",
+    "APCu" : "APCu",
+    "Redis" : "Redis",
+    "Security & setup warnings" : "Предупреждения безопасности и установки",
     "Sharing" : "Общий доступ",
-    "Security" : "Безопасность",
-    "Email Server" : "Почтовый сервер",
+    "Server-side encryption" : "Шифрование на стороне сервера",
+    "External Storage" : "Внешнее хранилище",
+    "Cron" : "Cron (планировщик задач)",
+    "Email server" : "Почтовый сервер",
     "Log" : "Журнал",
+    "Server Status" : "Статус сервера",
+    "Tips & tricks" : "Советы и трюки",
+    "Updates" : "Обновления",
     "Authentication error" : "Ошибка аутентификации",
     "Your full name has been changed." : "Ваше полное имя было изменено.",
     "Unable to change full name" : "Невозможно изменить полное имя",
-    "Files decrypted successfully" : "Расшифровка файлов прошло успешно",
-    "Couldn't decrypt your files, please check your owncloud.log or ask your administrator" : "Не удалось расшифровать ваши файлы, проверьте файл owncloud.log или обратитесь к вашему администратору.",
-    "Couldn't decrypt your files, check your password and try again" : "Ошибка при расшифровке файлов. Проверьте пароль и повторите попытку",
-    "Encryption keys deleted permanently" : "Ключи шифрования перманентно удалены",
-    "Couldn't permanently delete your encryption keys, please check your owncloud.log or ask your administrator" : "Не удалось удалить ваши ключи шифрования, проверьте файл owncloud.log или обратитесь к вашему администратору",
     "Couldn't remove app." : "Невозможно удалить приложение.",
-    "Backups restored successfully" : "Резервные копии успешно восстановлены",
-    "Couldn't restore your encryption keys, please check your owncloud.log or ask your administrator" : "Не удалось восстановить ваши ключи шифрования, проверьте файл owncloud.log или обратитесь к вашему администратору.",
     "Language changed" : "Язык изменён",
     "Invalid request" : "Неправильный запрос",
     "Admins can't remove themself from the admin group" : "Администратор не может удалить сам себя из группы администраторов",
@@ -28,22 +27,23 @@ OC.L10N.register(
     "No user supplied" : "Пользователь не задан",
     "Please provide an admin recovery password, otherwise all user data will be lost" : "Введите пароль восстановления администратора, в противном случае все пользовательские данные будут утеряны",
     "Wrong admin recovery password. Please check the password and try again." : "Неправильный пароль восстановления администратора. Проверьте пароль и попробуйте еще раз.",
-    "Back-end doesn't support password change, but the users encryption key was successfully updated." : "Используемый механизм не поддерживает смену паролей, но пользовательский ключ шифрования был успешно обновлён",
+    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Используемый механизм не поддерживает смену паролей, но пользовательский ключ шифрования был успешно обновлён",
     "Unable to change password" : "Невозможно изменить пароль",
     "Enabled" : "Включено",
     "Not enabled" : "Не включено",
-    "Recommended" : "Рекомендовано",
+    "A problem occurred, please check your log files (Error: %s)" : "Возникла проблема, пожалуйста, проверьте ваши файлы журнала (Ошибка: %s)",
+    "Migration Completed" : "Миграция завершена",
     "Group already exists." : "Группа уже существует.",
     "Unable to add group." : "Невозможно добавить группу.",
     "Unable to delete group." : "Невозможно удалить группу.",
     "log-level out of allowed range" : "уровень журнала вышел за разрешенный диапазон",
     "Saved" : "Сохранено",
     "test email settings" : "проверить настройки почты",
-    "If you received this email, the settings seem to be correct." : "Если вы получили это письмо, значит настройки верны.",
-    "A problem occurred while sending the email. Please revise your settings." : "Возникла проблема при отправке письма. Пожалуйста проверьте ваши настройки.",
+    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Во время отправки email произошла ошибка. Пожалуйста проверьте настройки. (Ошибка: %s)",
     "Email sent" : "Письмо отправлено",
     "You need to set your user email before being able to send test emails." : "Вы должны настроить свой e-mail пользователя прежде чем отправлять тестовые сообщения.",
     "Invalid mail address" : "Некорректный адрес email",
+    "A user with that name already exists." : "Пользователь с таким именем уже существует.",
     "Unable to create user." : "Невозможно создать пользователя.",
     "Your %s account was created" : "Учетная запись %s создана",
     "Unable to delete user." : "Невозможно удалить пользователя.",
@@ -53,8 +53,17 @@ OC.L10N.register(
     "Email saved" : "Email сохранен",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "Вы действительно хотите добавить домен \"{domain}\" как доверенный?",
     "Add trusted domain" : "Добавить доверенный домен",
+    "Migration in progress. Please wait until the migration is finished" : "Миграция в процессе. Пожалуйста, подождите завершения миграции",
+    "Migration started …" : "Начата миграция ...",
     "Sending..." : "Отправляется ...",
+    "Official" : "Официальное",
+    "Approved" : "Подтвержденное",
+    "Experimental" : "Экспериментальное",
     "All" : "Все",
+    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Официальные приложения разработаны силами сообщества ownCloud. Они полностью функциональны и готовы к работе.",
+    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Подтвержденные приложения разработаны доверенными разработчиками и прошли краткую проверку на наличие проблем с безопасностью. Они активно поддерживаются в открытых репозиториях и сопровождающие их разработчики подтверждают, что приложения достаточно стабильны для нормальной работы.",
+    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Это приложение не проверялось на наличие проблем с безопасностью, также оно может работать нестабильно. Устанавливайте на свой страх и риск.",
+    "Update to %s" : "Обновить до %s",
     "Please wait...." : "Пожалуйста подождите...",
     "Error while disabling app" : "Ошибка при отключении приложения",
     "Disable" : "Выключить",
@@ -74,9 +83,7 @@ OC.L10N.register(
     "Strong password" : "Стойкий пароль",
     "Valid until {date}" : "Действительно до {дата}",
     "Delete" : "Удалить",
-    "Decrypting files... Please wait, this can take some time." : "Расшифровка файлов... Пожалуйста подождите, это может занять некоторое время.",
-    "Delete encryption keys permanently." : "Перманентно удалить ключи шифрования. ",
-    "Restore encryption keys." : "Восстановить ключи шифрования.",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Произошла ошибка. Пожалуйста загрузите сертификат PEM в ASCII кодировке.",
     "Groups" : "Группы",
     "Unable to delete {objName}" : "Невозможно удалить {objName}",
     "Error creating group" : "Ошибка создания группы",
@@ -93,9 +100,9 @@ OC.L10N.register(
     "A valid password must be provided" : "Должен быть указан правильный пароль",
     "A valid email must be provided" : "Должен быть указан корректный адрес email",
     "__language_name__" : "Русский",
-    "Personal Info" : "Личная информация",
+    "Sync clients" : "Синхронизация клиентов",
+    "Personal info" : "Личная информация",
     "SSL root certificates" : "Корневые сертификаты SSL",
-    "Encryption" : "Шифрование",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Все (критические проблемы, ошибки, предупреждения, информационные, отладочные)",
     "Info, warnings, errors and fatal issues" : "Информационные, предупреждения, ошибки и критические проблемы",
     "Warnings, errors and fatal issues" : "Предупреждения, ошибки и критические проблемы",
@@ -107,38 +114,21 @@ OC.L10N.register(
     "NT LAN Manager" : "Менеджер NT LAN",
     "SSL" : "SSL",
     "TLS" : "TLS",
-    "Security Warning" : "Предупреждение безопасности",
-    "You are accessing %s via HTTP. We strongly suggest you configure your server to require using HTTPS instead." : "Вы обращаетесь к %s используя HTTP. Мы настоятельно рекомендуем вам настроить сервер на использование HTTPS.",
-    "Read-Only config enabled" : "Конфигурационный файл в режиме только для чтения",
+    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP был установлен неверно. Запрос getenv(\"PATH\") возвращает пустые результаты.",
+    "Please check the installation documentation for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Пожалуйста обратитесь к документации по установке для получения заметок по настройке php, а также к настройкам php вашего сервера, особенно это касается php-fpm.",
     "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Конфигурационный файл в режиме только для чтения. В связи с этим некоторые настройки веб-интерфейса невозможно изменить. Учтите, что для установки обновлений, вам потребуется самостоятельно разрешить запись в конфигурационный файл.",
-    "Setup Warning" : "Предупреждение установки",
     "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "Очевидно, PHP настроен на вычищение блоков встроенной документации. Это сделает несколько центральных приложений недоступными.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Возможно это вызвано кешем/ускорителем вроде Zend OPcache или eAccelerator.",
-    "Database Performance Info" : "Информация о производительности Базы Данных",
-    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "В качестве базы данных используется SQLite. Для больших установок мы рекомендуем переключиться на другую серверную базу данных.",
-    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Особенно вызывает сомнение использование SQLite при синхронизации файлов с использование клиента для ПК.",
-    "To migrate to another database use the command line tool: 'occ db:convert-type'" : "Для перехода на другую базу данных используйте команду: 'occ db:convert-type'",
-    "Microsoft Windows Platform" : "Платформа Microsoft Windows",
     "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Ваш сервер работает на ОС Microsoft Windows. Мы настоятельно рекомендуем использовать ОС семейства Linux для достижения наилучших условий использования.",
-    "Module 'fileinfo' missing" : "Модуль 'fileinfo' отсутствует",
+    "%1$s below version %2$s is installed, for stability and performance reasons we recommend to update to a newer %1$s version." : "%1$s ниже установленной версии %2$s, по причинам стабильности и производительности мы рекомендуем обновиться до новой версии %1$s.",
     "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP-модуль 'fileinfo' отсутствует. Мы настоятельно рекомендуем включить этот модуль для улучшения определения типов (mime-type) файлов.",
-    "PHP charset is not set to UTF-8" : "Кодировка PHP не установлена на UTF-8",
-    "PHP charset is not set to UTF-8. This can cause major issues with non-ASCII characters in file names. We highly recommend to change the value of 'default_charset' php.ini to 'UTF-8'." : "Кодировка PHP не установлена на UTF-8. Это может вызвать трудности с именами файлов, содержащими нелатинские символы. Мы настоятельно рекомендуем сменить значение переменной default_charset в файле php.ini на UTF-8.",
-    "Locale not working" : "Локализация не работает",
     "System locale can not be set to a one which supports UTF-8." : "Невозможно установить системную локаль, поддерживающую UTF-8",
     "This means that there might be problems with certain characters in file names." : "Это значит, что могут быть проблемы с некоторыми символами в именах файлов.",
     "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Мы рекомендуем установить требуемые пакеты для вашей системы для поддержки одного из следующих языков: %s.",
-    "URL generation in notification emails" : "Генерация URL в письмах уведомлениях",
     "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Если ваша копия ownCloud установлена не в корне домена и использует системный планировщик cron, возможны проблемы с правильной генерацией URL. Чтобы избежать этого, установите опцию \"overwrite.cli.url\" в файле config.php равной пути папки установки. (Предположительно: \"%s\".)",
-    "Configuration Checks" : "Проверка конфигурации",
-    "No problems found" : "Проблемы не найдены",
-    "Please double check the <a href='%s'>installation guides</a>." : "Подробно изучите <a href='%s'>инструкции по установке</a>.",
-    "Last cron was executed at %s." : "Последняя задача cron была запущена в %s.",
-    "Last cron was executed at %s. This is more than an hour ago, something seems wrong." : "Последняя задача cron запущена в %s. Это было больше часа назад, кажется что-то не так.",
-    "Cron was not executed yet!" : "Задачи cron ещё не запускались!",
-    "Execute one task with each page loaded" : "Выполнять одно задание с каждой загруженной страницей",
-    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php зарегистрирован в webcron и будет вызываться каждые 15 минут по http.",
-    "Use system's cron service to call the cron.php file every 15 minutes." : "Использовать системный cron для вызова cron.php каждые 15 минут.",
+    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Не удается запустить задачу планировщика через CLI. Произошли следующие технические ошибки:",
+    "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Пожалуйста, перепроверьте <a href=\"%s\">инструкцию по установке</a> и проверьте ошибки или предупреждения в <a href=\"#log-section\">журнале</a>",
+    "Open documentation" : "Открыть документацию",
     "Allow apps to use the Share API" : "Позволить приложениям использовать API общего доступа",
     "Allow users to share via link" : "Разрешить пользователям публикации через ссылки",
     "Enforce password protection" : "Защита паролем обязательна",
@@ -153,13 +143,23 @@ OC.L10N.register(
     "Allow users to send mail notification for shared files to other users" : "Разрешить пользователям отправлять оповещение других пользователей об открытии доступа к файлам",
     "Exclude groups from sharing" : "Исключить группы из общего доступа",
     "These groups will still be able to receive shares, but not to initiate them." : "Эти группы смогут получать общие ресурсы, но не могут их создавать.",
-    "Enforce HTTPS" : "HTTPS соединение обязательно",
-    "Forces the clients to connect to %s via an encrypted connection." : "Принудить клиентов подключаться к %s через шифрованное соединение.",
-    "Enforce HTTPS for subdomains" : "HTTPS соединение обязательно для субдоменов",
-    "Forces the clients to connect to %s and subdomains via an encrypted connection." : "Принудить клиентов подключаться к %s и субдоменам через шифрованное соединение.",
-    "Please connect to your %s via HTTPS to enable or disable the SSL enforcement." : "Пожалуйста, подключитесь к %s используя HTTPS чтобы включить или отключить обязательные SSL подключения.",
+    "Last cron job execution: %s." : "Последнее выполненное Cron задание: %s.",
+    "Last cron job execution: %s. Something seems wrong." : "Последнее выполненное Cron задание: %s. Что-то кажется неправильным.",
+    "Cron was not executed yet!" : "Задачи cron ещё не запускались!",
+    "Execute one task with each page loaded" : "Выполнять одно задание с каждой загруженной страницей",
+    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php зарегистрирован в webcron и будет вызываться каждые 15 минут по http.",
+    "Use system's cron service to call the cron.php file every 15 minutes." : "Использовать системный cron для вызова cron.php каждые 15 минут.",
+    "Enable server-side encryption" : "Включить шифрование на стороне сервера",
+    "Encryption is a one way process. Once encryption is enabled, all files from that point forward will be encrypted on the server and it will not be possible to disable encryption at a later date. This is the final warning: Do you really want to enable encryption?" : "Шифрование это односторонний процесс. После включения шифрования все файлы будут зашифрованы на сервере, позднее его нельзя будет отключить. Это последнее предупреждение: вы действительно хотите включить шифрование?",
+    "Enable encryption" : "Включить шифрование",
+    "No encryption module loaded, please enable an encryption module in the app menu." : "Модуль шифрования не загружен, пожалуйста включите модуль шифрования в меню приложений.",
+    "Select default encryption module:" : "Выберите модуль шифрования по умолчанию:",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Вам необходимо произвести конвертацию ключей шифрования из старого формата (ownCloud <= 8.0) в новый. Пожалуйста включите \"Модуль шифрования по умолчанию\" и запустите команду 'occ encryption:migrate'.",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Вам необходимо произвести конвертацию ключей шифрования из старого формата (ownCloud <= 8.0) в новый.",
+    "Start migration" : "Запустить миграцию",
     "This is used for sending out notifications." : "Используется для отправки уведомлений.",
     "Send mode" : "Способ отправки",
+    "Encryption" : "Шифрование",
     "From address" : "Адрес отправителя",
     "mail" : "почта",
     "Authentication method" : "Метод проверки подлинности",
@@ -176,47 +176,62 @@ OC.L10N.register(
     "Download logfile" : "Скачать журнал",
     "More" : "Больше",
     "Less" : "Меньше",
-    "The logfile is bigger than 100MB. Downloading it may take some time!" : "Размер журнала превышает 100MB. Скачивание может занять некоторое время.",
+    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Лог-файл - больше 100 мб. Его скачивание может занять некоторое время!",
+    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "В качестве базы данных используется SQLite. Для больших установок мы рекомендуем переключиться на другую серверную базу данных.",
+    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Особенно вызывает сомнение использование SQLite при синхронизации файлов с использование клиента для ПК.",
+    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "Для перехода на другую базу данных используйте команду: 'occ db:convert-type' или ознакомьтесь с <a target=\"_blank\" href=\"%s\">документацией ↗</a>.",
+    "How to do backups" : "Как сделать резервные копии",
+    "Advanced monitoring" : "Расширенный мониторинг",
+    "Performance tuning" : "Настройка производительности",
+    "Improving the config.php" : "Улучшение config.php",
+    "Theming" : "Темы оформления",
+    "Hardening and security guidance" : "Руководство по безопасности и защите",
+    "Transactional File Locking is enabled." : "Транзакционная блокировка файлов включена.",
+    "Transactional File Locking is disabled." : "Транзакционная блокировка файлов отключена.",
     "Version" : "Версия",
-    "Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." : "Разрабатывается <a href=\"http://ownCloud.org/contact\" target=\"_blank\">сообществом ownCloud</a>, <a href=\"https://github.com/owncloud\" target=\"_blank\">исходный код</a> доступен под лицензией <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>.",
-    "More apps" : "Ещё приложения",
-    "Add your app" : "Добавить своё приложение",
+    "Developer documentation" : "Документация для разработчиков",
+    "Experimental applications ahead" : "Экспериментальные приложения",
+    "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "Экспериментальные приложения не проверялись на наличие уязвимостей безопасности, они также могут быть нестабильны, т.к. находятся в активной разработке. Их установка может повлечь потерю информации или нарушение безопасности.",
     "by" : "автор",
     "licensed" : "Лицензировано",
     "Documentation:" : "Документация:",
     "User Documentation" : "Пользовательская документация",
     "Admin Documentation" : "Документация администратора",
+    "Show description …" : "Показать описание ...",
+    "Hide description …" : "Скрыть описание ...",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Приложение не может быть установлено, следующие зависимости не удовлетворены:",
-    "Update to %s" : "Обновить до %s",
     "Enable only for specific groups" : "Включить только для этих групп",
     "Uninstall App" : "Удалить приложение",
+    "Enable experimental apps" : "Включить экспериментальные приложения",
+    "No apps found for your version" : "Не найдено приложений на вашу версию",
     "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Здравствуйте,<br><br>просто хотим сообщить, что теперь у вас есть учетная запись на %s.<br><br>Ваше имя пользователя: %s<br>Зайти: <a href=\"%s\">%s</a><br><br>",
     "Cheers!" : "Удачи!",
     "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Здравствуйте,\n\nПросто хотим сообщить, что теперь у вас есть учетная запись на %s.\n\nИмя пользователя: %s\nЗайти: %s\n",
-    "Administrator Documentation" : "Документация администратора",
-    "Online Documentation" : "Online документация",
+    "User documentation" : "Пользовательская документация",
+    "Administrator documentation" : "Документация администратора",
+    "Online documentation" : "Online-документация",
     "Forum" : "Форум",
-    "Bugtracker" : "Багтрекер",
-    "Commercial Support" : "Коммерческая поддержка",
+    "Issue tracker" : "трекер проблем",
+    "Commercial support" : "Коммерческая поддержка",
     "Get the apps to sync your files" : "Получить приложения для синхронизации ваших файлов",
     "Desktop client" : "Клиент для ПК",
     "Android app" : "Android приложение",
     "iOS app" : "iOS приложение",
-    "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\">spread the word</a>!" : "Если вы хотите поддержать проект,\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\">присоединяйтесь к разработке</a>\n\t\tили\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\">содействуйте распространению</a>!",
+    "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Если Вы хотите поддержать проект\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">совместная разработка</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">сообщить</a>!",
     "Show First Run Wizard again" : "Показать помощник настройки снова",
     "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "Вы использовали <strong>%s</strong> из доступных <strong>%s</strong>",
     "Password" : "Пароль",
-    "Your password was changed" : "Ваш пароль был изменён",
     "Unable to change your password" : "Невозможно сменить пароль",
     "Current password" : "Текущий пароль",
     "New password" : "Новый пароль",
     "Change password" : "Сменить пароль",
-    "Full Name" : "Полное имя",
+    "Full name" : "Полное имя",
     "No display name set" : "Отображаемое имя не указано",
     "Email" : "E-mail",
     "Your email address" : "Ваш адрес электронной почты",
     "Fill in an email address to enable password recovery and receive notifications" : "Введите свой email-адрес для того, чтобы включить возможность восстановления пароля и получения уведомлений",
     "No email address set" : "E-mail не указан",
+    "You are member of the following groups:" : "Вы являетесь членом следующих групп:",
     "Profile picture" : "Аватар",
     "Upload new" : "Загрузить новый",
     "Select new from Files" : "Выберите новый из файлов",
@@ -231,13 +246,8 @@ OC.L10N.register(
     "Valid until" : "Действительно до",
     "Issued By" : "Выдан",
     "Valid until %s" : "Действительно до %s",
-    "Import Root Certificate" : "Импортировать корневые сертификаты",
-    "The encryption app is no longer enabled, please decrypt all your files" : "Приложение шифрования больше не используется, пожалуйста расшифруйте все ваши файлы",
-    "Log-in password" : "Пароль входа",
-    "Decrypt all Files" : "Снять шифрование со всех файлов",
-    "Your encryption keys are moved to a backup location. If something went wrong you can restore the keys. Only delete them permanently if you are sure that all files are decrypted correctly." : "Ключи шифрования были перемещены в папку с резервными копиями. Если что-то пойдёт не так, то вы сможете восстановить ключи. Удаляйте ключи из архива только тогда, когда вы будете уверены, что все файлы были успешно расшифрованы.",
-    "Restore Encryption Keys" : "Восстановить Ключи Шифрования",
-    "Delete Encryption Keys" : "Удалить Ключи Шифрования",
+    "Import root certificate" : "Импорт корневого сертификата",
+    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Разработано {communityopen}сообществом ownCloud{linkclose}, {githubopen}исходный код{linkclose} лицензируется в соответствии с{licenseopen}<abbr title=\"Публичной лицензией Affero General\">AGPL</abbr>{linkclose}.",
     "Show storage location" : "Показать местонахождение хранилища",
     "Show last log in" : "Показать последний вход в систему",
     "Show user backend" : "Показать пользовательскую часть",
@@ -257,6 +267,7 @@ OC.L10N.register(
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Пожалуйста, введите квоту на хранилище (например: \"512 MB\" или \"12 GB\")",
     "Unlimited" : "Неограничено",
     "Other" : "Другая",
+    "Full Name" : "Полное имя",
     "Group Admin for" : "Для группы Администраторов",
     "Quota" : "Квота",
     "Storage Location" : "Место хранилища",
@@ -267,4 +278,4 @@ OC.L10N.register(
     "change email address" : "изменить адрес email",
     "Default" : "По умолчанию"
 },
-"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
+"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
